/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.8.6
 *
 * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtCore.h"

#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 29 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQLocale.cpp"

#line 27 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 33 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQLocale.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 36 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQLocale.cpp"
#line 36 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 39 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQLocale.cpp"
#line 38 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 42 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQLocale.cpp"
#line 856 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <Qt>
#line 45 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQLocale.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 48 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQLocale.cpp"
#line 27 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qchar.sip"
#include <qchar.h>
#line 51 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQLocale.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 54 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQLocale.cpp"
#line 360 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qdatetime.sip"
#include <qdatetime.h>
#line 57 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQLocale.cpp"
#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcalendar.sip"
#include <qcalendar.h>
#line 60 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQLocale.cpp"
#line 216 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qdatetime.sip"
#include <qdatetime.h>
#line 63 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQLocale.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qdatetime.sip"
#include <qdatetime.h>
#line 66 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQLocale.cpp"


PyDoc_STRVAR(doc_QLocale_language, "language(self) -> QLocale.Language");

extern "C" {static PyObject *meth_QLocale_language(PyObject *, PyObject *);}
static PyObject *meth_QLocale_language(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QLocale::Language sipRes;

            sipRes = sipCpp->language();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLocale_Language);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_language, doc_QLocale_language);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_country, "country(self) -> QLocale.Country");

extern "C" {static PyObject *meth_QLocale_country(PyObject *, PyObject *);}
static PyObject *meth_QLocale_country(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QLocale::Country sipRes;

            sipRes = sipCpp->country();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLocale_Country);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_country, doc_QLocale_country);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_name, "name(self) -> str");

extern "C" {static PyObject *meth_QLocale_name(PyObject *, PyObject *);}
static PyObject *meth_QLocale_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_name, doc_QLocale_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toShort, "toShort(self, s: Optional[str]) -> (int, Optional[bool])");

extern "C" {static PyObject *meth_QLocale_toShort(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toShort(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        bool a1;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State))
        {
            short sipRes;

            sipRes = sipCpp->toShort(*a0, &a1);
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            return sipBuildResult(0, "(hb)", sipRes, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toShort, doc_QLocale_toShort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toUShort, "toUShort(self, s: Optional[str]) -> (int, Optional[bool])");

extern "C" {static PyObject *meth_QLocale_toUShort(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toUShort(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        bool a1;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::ushort sipRes;

            sipRes = sipCpp->toUShort(*a0, &a1);
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            return sipBuildResult(0, "(tb)", sipRes, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toUShort, doc_QLocale_toUShort);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toInt, "toInt(self, s: Optional[str]) -> (int, Optional[bool])");

extern "C" {static PyObject *meth_QLocale_toInt(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toInt(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        bool a1;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State))
        {
            int sipRes;

            sipRes = sipCpp->toInt(*a0, &a1);
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            return sipBuildResult(0, "(ib)", sipRes, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toInt, doc_QLocale_toInt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toUInt, "toUInt(self, s: Optional[str]) -> (int, Optional[bool])");

extern "C" {static PyObject *meth_QLocale_toUInt(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toUInt(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        bool a1;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::uint sipRes;

            sipRes = sipCpp->toUInt(*a0, &a1);
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            return sipBuildResult(0, "(ub)", sipRes, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toUInt, doc_QLocale_toUInt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toLongLong, "toLongLong(self, s: Optional[str]) -> (int, Optional[bool])");

extern "C" {static PyObject *meth_QLocale_toLongLong(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toLongLong(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        bool a1;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::qlonglong sipRes;

            sipRes = sipCpp->toLongLong(*a0, &a1);
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            return sipBuildResult(0, "(nb)", sipRes, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toLongLong, doc_QLocale_toLongLong);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toULongLong, "toULongLong(self, s: Optional[str]) -> (int, Optional[bool])");

extern "C" {static PyObject *meth_QLocale_toULongLong(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toULongLong(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        bool a1;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::qulonglong sipRes;

            sipRes = sipCpp->toULongLong(*a0, &a1);
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            return sipBuildResult(0, "(ob)", sipRes, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toULongLong, doc_QLocale_toULongLong);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toFloat, "toFloat(self, s: Optional[str]) -> (float, Optional[bool])");

extern "C" {static PyObject *meth_QLocale_toFloat(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toFloat(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        bool a1;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State))
        {
            float sipRes;

            sipRes = sipCpp->toFloat(*a0, &a1);
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            return sipBuildResult(0, "(fb)", sipRes, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toFloat, doc_QLocale_toFloat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toDouble, "toDouble(self, s: Optional[str]) -> (float, Optional[bool])");

extern "C" {static PyObject *meth_QLocale_toDouble(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toDouble(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        bool a1;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State))
        {
            double sipRes;

            sipRes = sipCpp->toDouble(*a0, &a1);
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            return sipBuildResult(0, "(db)", sipRes, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toDouble, doc_QLocale_toDouble);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toString, "toString(self, i: float, format: str = 'g', precision: int = 6) -> str\n"
"toString(self, dateTime: Union[QDateTime, datetime.datetime], format: Optional[str]) -> str\n"
"toString(self, dateTime: Union[QDateTime, datetime.datetime], formatStr: Optional[str], cal: QCalendar) -> str\n"
"toString(self, dateTime: Union[QDateTime, datetime.datetime], format: QLocale.FormatType = QLocale.LongFormat) -> str\n"
"toString(self, dateTime: Union[QDateTime, datetime.datetime], format: QLocale.FormatType, cal: QCalendar) -> str\n"
"toString(self, date: Union[QDate, datetime.date], formatStr: Optional[str]) -> str\n"
"toString(self, date: Union[QDate, datetime.date], formatStr: Optional[str], cal: QCalendar) -> str\n"
"toString(self, date: Union[QDate, datetime.date], format: QLocale.FormatType = QLocale.LongFormat) -> str\n"
"toString(self, date: Union[QDate, datetime.date], format: QLocale.FormatType, cal: QCalendar) -> str\n"
"toString(self, time: Union[QTime, datetime.time], formatStr: Optional[str]) -> str\n"
"toString(self, time: Union[QTime, datetime.time], format: QLocale.FormatType = QLocale.LongFormat) -> str\n"
"toString(self, i: int) -> str");

extern "C" {static PyObject *meth_QLocale_toString(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toString(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        double a0;
        char a1 = 'g';
        int a2 = 6;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
            sipName_precision,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BXd|aAi", &sipSelf, sipType_QLocale, &sipCpp, &a0, &a1, &a2))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString(a0, a1, a2));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        const ::QDateTime* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1J1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QDateTime, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString(*a0, *a1));
            sipReleaseType(const_cast<::QDateTime *>(a0), sipType_QDateTime, a0State);
            sipReleaseType(const_cast<::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        const ::QDateTime* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        ::QCalendar* a2;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1J1J9", &sipSelf, sipType_QLocale, &sipCpp, sipType_QDateTime, &a0, &a0State, sipType_QString, &a1, &a1State, sipType_QCalendar, &a2))
        {
            ::QString*sipRes = 0;

#line 992 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qlocale.sip"
        // QStringView has issues being implemented as a mapped type.
        sipRes = new QString(sipCpp->toString(*a0, QStringView(*a1), *a2));
#line 493 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQLocale.cpp"
            sipReleaseType(const_cast<::QDateTime *>(a0), sipType_QDateTime, a0State);
            sipReleaseType(const_cast<::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        const ::QDateTime* a0;
        int a0State = 0;
        ::QLocale::FormatType a1 = QLocale::LongFormat;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|E", &sipSelf, sipType_QLocale, &sipCpp, sipType_QDateTime, &a0, &a0State, sipType_QLocale_FormatType, &a1))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString(*a0, a1));
            sipReleaseType(const_cast<::QDateTime *>(a0), sipType_QDateTime, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        const ::QDateTime* a0;
        int a0State = 0;
        ::QLocale::FormatType a1;
        ::QCalendar* a2;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1EJ9", &sipSelf, sipType_QLocale, &sipCpp, sipType_QDateTime, &a0, &a0State, sipType_QLocale_FormatType, &a1, sipType_QCalendar, &a2))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString(*a0, a1, *a2));
            sipReleaseType(const_cast<::QDateTime *>(a0), sipType_QDateTime, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        const ::QDate* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1J1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QDate, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString(*a0, *a1));
            sipReleaseType(const_cast<::QDate *>(a0), sipType_QDate, a0State);
            sipReleaseType(const_cast<::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        const ::QDate* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        ::QCalendar* a2;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1J1J9", &sipSelf, sipType_QLocale, &sipCpp, sipType_QDate, &a0, &a0State, sipType_QString, &a1, &a1State, sipType_QCalendar, &a2))
        {
            ::QString*sipRes = 0;

#line 1005 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qlocale.sip"
        // QStringView has issues being implemented as a mapped type.
        sipRes = new QString(sipCpp->toString(*a0, QStringView(*a1), *a2));
#line 575 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQLocale.cpp"
            sipReleaseType(const_cast<::QDate *>(a0), sipType_QDate, a0State);
            sipReleaseType(const_cast<::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        const ::QDate* a0;
        int a0State = 0;
        ::QLocale::FormatType a1 = QLocale::LongFormat;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|E", &sipSelf, sipType_QLocale, &sipCpp, sipType_QDate, &a0, &a0State, sipType_QLocale_FormatType, &a1))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString(*a0, a1));
            sipReleaseType(const_cast<::QDate *>(a0), sipType_QDate, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        const ::QDate* a0;
        int a0State = 0;
        ::QLocale::FormatType a1;
        ::QCalendar* a2;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1EJ9", &sipSelf, sipType_QLocale, &sipCpp, sipType_QDate, &a0, &a0State, sipType_QLocale_FormatType, &a1, sipType_QCalendar, &a2))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString(*a0, a1, *a2));
            sipReleaseType(const_cast<::QDate *>(a0), sipType_QDate, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        const ::QTime* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1J1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QTime, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString(*a0, *a1));
            sipReleaseType(const_cast<::QTime *>(a0), sipType_QTime, a0State);
            sipReleaseType(const_cast<::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        const ::QTime* a0;
        int a0State = 0;
        ::QLocale::FormatType a1 = QLocale::LongFormat;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|E", &sipSelf, sipType_QLocale, &sipCpp, sipType_QTime, &a0, &a0State, sipType_QLocale_FormatType, &a1))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toString(*a0, a1));
            sipReleaseType(const_cast<::QTime *>(a0), sipType_QTime, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        PyObject * a0;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BP0", &sipSelf, sipType_QLocale, &sipCpp, &a0))
        {
            ::QString*sipRes = 0;
            sipErrorState sipError = sipErrorNone;

#line 1465 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qlocale.sip"
        // Convert a Python int avoiding overflow as much as possible.
        
        static PyObject *zero = 0;
        if (!zero)
            zero = PyLong_FromLong(0);
        
        int rc = PyObject_RichCompareBool(a0, zero, Py_LT);
        
        PyErr_Clear();
        
        if (rc < 0)
        {
            sipError = sipBadCallableArg(0, a0);
        }
        else if (rc)
        {
        #if defined(HAVE_LONG_LONG)
            PY_LONG_LONG value = PyLong_AsLongLong(a0);
        #else
            long value = PyLong_AsLong(a0);
        #endif
        
            if (PyErr_Occurred() && !PyErr_ExceptionMatches(PyExc_OverflowError))
            {
                sipError = sipBadCallableArg(0, a0);
            }
            else
            {
                sipRes = new QString(sipCpp->toString(value));
            }
        }
        else
        {
        #if PY_MAJOR_VERSION >= 3
        #if defined(HAVE_LONG_LONG)
            unsigned PY_LONG_LONG value = PyLong_AsUnsignedLongLongMask(a0);
        #else
            unsigned long value = PyLong_AsUnsignedLongMask(a0);
        #endif
        #else
        #if defined(HAVE_LONG_LONG)
            unsigned PY_LONG_LONG value = PyInt_AsUnsignedLongLongMask(a0);
        #else
            unsigned long value = PyInt_AsUnsignedLongMask(a0);
        #endif
        #endif
        
            if (PyErr_Occurred() && !PyErr_ExceptionMatches(PyExc_OverflowError))
            {
                sipError = sipBadCallableArg(0, a0);
            }
            else
            {
                sipRes = new QString(sipCpp->toString(value));
            }
        }
#line 730 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQLocale.cpp"

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toString, doc_QLocale_toString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_languageToString, "languageToString(language: QLocale.Language) -> str");

extern "C" {static PyObject *meth_QLocale_languageToString(PyObject *, PyObject *);}
static PyObject *meth_QLocale_languageToString(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLocale::Language a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "E", sipType_QLocale_Language, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QLocale::languageToString(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_languageToString, doc_QLocale_languageToString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_countryToString, "countryToString(country: QLocale.Country) -> str");

extern "C" {static PyObject *meth_QLocale_countryToString(PyObject *, PyObject *);}
static PyObject *meth_QLocale_countryToString(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLocale::Country a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "E", sipType_QLocale_Country, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QLocale::countryToString(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_countryToString, doc_QLocale_countryToString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_setDefault, "setDefault(locale: QLocale)");

extern "C" {static PyObject *meth_QLocale_setDefault(PyObject *, PyObject *);}
static PyObject *meth_QLocale_setDefault(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J9", sipType_QLocale, &a0))
        {
            ::QLocale::setDefault(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_setDefault, doc_QLocale_setDefault);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_c, "c() -> QLocale");

extern "C" {static PyObject *meth_QLocale_c(PyObject *, PyObject *);}
static PyObject *meth_QLocale_c(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QLocale*sipRes;

            sipRes = new ::QLocale(::QLocale::c());

            return sipConvertFromNewType(sipRes, sipType_QLocale, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_c, doc_QLocale_c);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_system, "system() -> QLocale");

extern "C" {static PyObject *meth_QLocale_system(PyObject *, PyObject *);}
static PyObject *meth_QLocale_system(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QLocale*sipRes;

            sipRes = new ::QLocale(::QLocale::system());

            return sipConvertFromNewType(sipRes, sipType_QLocale, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_system, doc_QLocale_system);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_dateFormat, "dateFormat(self, format: QLocale.FormatType = QLocale.LongFormat) -> str");

extern "C" {static PyObject *meth_QLocale_dateFormat(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_dateFormat(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLocale::FormatType a0 = QLocale::LongFormat;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|E", &sipSelf, sipType_QLocale, &sipCpp, sipType_QLocale_FormatType, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->dateFormat(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_dateFormat, doc_QLocale_dateFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_timeFormat, "timeFormat(self, format: QLocale.FormatType = QLocale.LongFormat) -> str");

extern "C" {static PyObject *meth_QLocale_timeFormat(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_timeFormat(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLocale::FormatType a0 = QLocale::LongFormat;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|E", &sipSelf, sipType_QLocale, &sipCpp, sipType_QLocale_FormatType, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->timeFormat(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_timeFormat, doc_QLocale_timeFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_dateTimeFormat, "dateTimeFormat(self, format: QLocale.FormatType = QLocale.LongFormat) -> str");

extern "C" {static PyObject *meth_QLocale_dateTimeFormat(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_dateTimeFormat(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLocale::FormatType a0 = QLocale::LongFormat;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|E", &sipSelf, sipType_QLocale, &sipCpp, sipType_QLocale_FormatType, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->dateTimeFormat(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_dateTimeFormat, doc_QLocale_dateTimeFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toDate, "toDate(self, string: Optional[str], format: QLocale.FormatType = QLocale.LongFormat) -> QDate\n"
"toDate(self, string: Optional[str], format: Optional[str]) -> QDate\n"
"toDate(self, string: Optional[str], format: QLocale.FormatType, cal: QCalendar) -> QDate\n"
"toDate(self, string: Optional[str], format: Optional[str], cal: QCalendar) -> QDate");

extern "C" {static PyObject *meth_QLocale_toDate(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toDate(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QLocale::FormatType a1 = QLocale::LongFormat;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|E", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State, sipType_QLocale_FormatType, &a1))
        {
            ::QDate*sipRes;

            sipRes = new ::QDate(sipCpp->toDate(*a0, a1));
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QDate, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1J1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            ::QDate*sipRes;

            sipRes = new ::QDate(sipCpp->toDate(*a0, *a1));
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast<::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QDate, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::QLocale::FormatType a1;
        ::QCalendar* a2;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1EJ9", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State, sipType_QLocale_FormatType, &a1, sipType_QCalendar, &a2))
        {
            ::QDate*sipRes;

            sipRes = new ::QDate(sipCpp->toDate(*a0, a1, *a2));
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QDate, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        ::QCalendar* a2;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1J1J9", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State, sipType_QCalendar, &a2))
        {
            ::QDate*sipRes;

            sipRes = new ::QDate(sipCpp->toDate(*a0, *a1, *a2));
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast<::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QDate, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toDate, doc_QLocale_toDate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toTime, "toTime(self, string: Optional[str], format: QLocale.FormatType = QLocale.LongFormat) -> QTime\n"
"toTime(self, string: Optional[str], format: Optional[str]) -> QTime\n"
"toTime(self, string: Optional[str], format: QLocale.FormatType, cal: QCalendar) -> QTime\n"
"toTime(self, string: Optional[str], format: Optional[str], cal: QCalendar) -> QTime");

extern "C" {static PyObject *meth_QLocale_toTime(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toTime(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QLocale::FormatType a1 = QLocale::LongFormat;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|E", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State, sipType_QLocale_FormatType, &a1))
        {
            ::QTime*sipRes;

            sipRes = new ::QTime(sipCpp->toTime(*a0, a1));
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QTime, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1J1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            ::QTime*sipRes;

            sipRes = new ::QTime(sipCpp->toTime(*a0, *a1));
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast<::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QTime, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::QLocale::FormatType a1;
        ::QCalendar* a2;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1EJ9", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State, sipType_QLocale_FormatType, &a1, sipType_QCalendar, &a2))
        {
            ::QTime*sipRes;

            sipRes = new ::QTime(sipCpp->toTime(*a0, a1, *a2));
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QTime, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        ::QCalendar* a2;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1J1J9", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State, sipType_QCalendar, &a2))
        {
            ::QTime*sipRes;

            sipRes = new ::QTime(sipCpp->toTime(*a0, *a1, *a2));
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast<::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QTime, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toTime, doc_QLocale_toTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toDateTime, "toDateTime(self, string: Optional[str], format: QLocale.FormatType = QLocale.LongFormat) -> QDateTime\n"
"toDateTime(self, string: Optional[str], format: Optional[str]) -> QDateTime\n"
"toDateTime(self, string: Optional[str], format: QLocale.FormatType, cal: QCalendar) -> QDateTime\n"
"toDateTime(self, string: Optional[str], format: Optional[str], cal: QCalendar) -> QDateTime");

extern "C" {static PyObject *meth_QLocale_toDateTime(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toDateTime(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QLocale::FormatType a1 = QLocale::LongFormat;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|E", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State, sipType_QLocale_FormatType, &a1))
        {
            ::QDateTime*sipRes;

            sipRes = new ::QDateTime(sipCpp->toDateTime(*a0, a1));
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QDateTime, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1J1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            ::QDateTime*sipRes;

            sipRes = new ::QDateTime(sipCpp->toDateTime(*a0, *a1));
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast<::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QDateTime, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        ::QLocale::FormatType a1;
        ::QCalendar* a2;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1EJ9", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State, sipType_QLocale_FormatType, &a1, sipType_QCalendar, &a2))
        {
            ::QDateTime*sipRes;

            sipRes = new ::QDateTime(sipCpp->toDateTime(*a0, a1, *a2));
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QDateTime, SIP_NULLPTR);
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        ::QCalendar* a2;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BJ1J1J9", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State, sipType_QString, &a1, &a1State, sipType_QCalendar, &a2))
        {
            ::QDateTime*sipRes;

            sipRes = new ::QDateTime(sipCpp->toDateTime(*a0, *a1, *a2));
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast<::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QDateTime, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toDateTime, doc_QLocale_toDateTime);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_decimalPoint, "decimalPoint(self) -> str");

extern "C" {static PyObject *meth_QLocale_decimalPoint(PyObject *, PyObject *);}
static PyObject *meth_QLocale_decimalPoint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QChar*sipRes;

            sipRes = new ::QChar(sipCpp->decimalPoint());

            return sipConvertFromNewType(sipRes, sipType_QChar, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_decimalPoint, doc_QLocale_decimalPoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_groupSeparator, "groupSeparator(self) -> str");

extern "C" {static PyObject *meth_QLocale_groupSeparator(PyObject *, PyObject *);}
static PyObject *meth_QLocale_groupSeparator(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QChar*sipRes;

            sipRes = new ::QChar(sipCpp->groupSeparator());

            return sipConvertFromNewType(sipRes, sipType_QChar, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_groupSeparator, doc_QLocale_groupSeparator);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_percent, "percent(self) -> str");

extern "C" {static PyObject *meth_QLocale_percent(PyObject *, PyObject *);}
static PyObject *meth_QLocale_percent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QChar*sipRes;

            sipRes = new ::QChar(sipCpp->percent());

            return sipConvertFromNewType(sipRes, sipType_QChar, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_percent, doc_QLocale_percent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_zeroDigit, "zeroDigit(self) -> str");

extern "C" {static PyObject *meth_QLocale_zeroDigit(PyObject *, PyObject *);}
static PyObject *meth_QLocale_zeroDigit(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QChar*sipRes;

            sipRes = new ::QChar(sipCpp->zeroDigit());

            return sipConvertFromNewType(sipRes, sipType_QChar, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_zeroDigit, doc_QLocale_zeroDigit);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_negativeSign, "negativeSign(self) -> str");

extern "C" {static PyObject *meth_QLocale_negativeSign(PyObject *, PyObject *);}
static PyObject *meth_QLocale_negativeSign(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QChar*sipRes;

            sipRes = new ::QChar(sipCpp->negativeSign());

            return sipConvertFromNewType(sipRes, sipType_QChar, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_negativeSign, doc_QLocale_negativeSign);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_exponential, "exponential(self) -> str");

extern "C" {static PyObject *meth_QLocale_exponential(PyObject *, PyObject *);}
static PyObject *meth_QLocale_exponential(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QChar*sipRes;

            sipRes = new ::QChar(sipCpp->exponential());

            return sipConvertFromNewType(sipRes, sipType_QChar, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_exponential, doc_QLocale_exponential);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_monthName, "monthName(self, a0: int, format: QLocale.FormatType = QLocale.LongFormat) -> str");

extern "C" {static PyObject *meth_QLocale_monthName(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_monthName(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QLocale::FormatType a1 = QLocale::LongFormat;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|E", &sipSelf, sipType_QLocale, &sipCpp, &a0, sipType_QLocale_FormatType, &a1))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->monthName(a0, a1));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_monthName, doc_QLocale_monthName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_dayName, "dayName(self, a0: int, format: QLocale.FormatType = QLocale.LongFormat) -> str");

extern "C" {static PyObject *meth_QLocale_dayName(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_dayName(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QLocale::FormatType a1 = QLocale::LongFormat;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|E", &sipSelf, sipType_QLocale, &sipCpp, &a0, sipType_QLocale_FormatType, &a1))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->dayName(a0, a1));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_dayName, doc_QLocale_dayName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_setNumberOptions, "setNumberOptions(self, options: Union[QLocale.NumberOptions, QLocale.NumberOption])");

extern "C" {static PyObject *meth_QLocale_setNumberOptions(PyObject *, PyObject *);}
static PyObject *meth_QLocale_setNumberOptions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLocale::NumberOptions* a0;
        int a0State = 0;
        ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QLocale_NumberOptions, &a0, &a0State))
        {
            sipCpp->setNumberOptions(*a0);
            sipReleaseType(a0, sipType_QLocale_NumberOptions, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_setNumberOptions, doc_QLocale_setNumberOptions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_numberOptions, "numberOptions(self) -> QLocale.NumberOptions");

extern "C" {static PyObject *meth_QLocale_numberOptions(PyObject *, PyObject *);}
static PyObject *meth_QLocale_numberOptions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QLocale::NumberOptions*sipRes;

            sipRes = new ::QLocale::NumberOptions(sipCpp->numberOptions());

            return sipConvertFromNewType(sipRes, sipType_QLocale_NumberOptions, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_numberOptions, doc_QLocale_numberOptions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_measurementSystem, "measurementSystem(self) -> QLocale.MeasurementSystem");

extern "C" {static PyObject *meth_QLocale_measurementSystem(PyObject *, PyObject *);}
static PyObject *meth_QLocale_measurementSystem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QLocale::MeasurementSystem sipRes;

            sipRes = sipCpp->measurementSystem();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLocale_MeasurementSystem);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_measurementSystem, doc_QLocale_measurementSystem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_positiveSign, "positiveSign(self) -> str");

extern "C" {static PyObject *meth_QLocale_positiveSign(PyObject *, PyObject *);}
static PyObject *meth_QLocale_positiveSign(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QChar*sipRes;

            sipRes = new ::QChar(sipCpp->positiveSign());

            return sipConvertFromNewType(sipRes, sipType_QChar, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_positiveSign, doc_QLocale_positiveSign);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_standaloneMonthName, "standaloneMonthName(self, a0: int, format: QLocale.FormatType = QLocale.LongFormat) -> str");

extern "C" {static PyObject *meth_QLocale_standaloneMonthName(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_standaloneMonthName(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QLocale::FormatType a1 = QLocale::LongFormat;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|E", &sipSelf, sipType_QLocale, &sipCpp, &a0, sipType_QLocale_FormatType, &a1))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->standaloneMonthName(a0, a1));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_standaloneMonthName, doc_QLocale_standaloneMonthName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_standaloneDayName, "standaloneDayName(self, a0: int, format: QLocale.FormatType = QLocale.LongFormat) -> str");

extern "C" {static PyObject *meth_QLocale_standaloneDayName(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_standaloneDayName(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QLocale::FormatType a1 = QLocale::LongFormat;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bi|E", &sipSelf, sipType_QLocale, &sipCpp, &a0, sipType_QLocale_FormatType, &a1))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->standaloneDayName(a0, a1));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_standaloneDayName, doc_QLocale_standaloneDayName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_amText, "amText(self) -> str");

extern "C" {static PyObject *meth_QLocale_amText(PyObject *, PyObject *);}
static PyObject *meth_QLocale_amText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->amText());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_amText, doc_QLocale_amText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_pmText, "pmText(self) -> str");

extern "C" {static PyObject *meth_QLocale_pmText(PyObject *, PyObject *);}
static PyObject *meth_QLocale_pmText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->pmText());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_pmText, doc_QLocale_pmText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_textDirection, "textDirection(self) -> Qt.LayoutDirection");

extern "C" {static PyObject *meth_QLocale_textDirection(PyObject *, PyObject *);}
static PyObject *meth_QLocale_textDirection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::Qt::LayoutDirection sipRes;

            sipRes = sipCpp->textDirection();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_LayoutDirection);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_textDirection, doc_QLocale_textDirection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_script, "script(self) -> QLocale.Script");

extern "C" {static PyObject *meth_QLocale_script(PyObject *, PyObject *);}
static PyObject *meth_QLocale_script(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QLocale::Script sipRes;

            sipRes = sipCpp->script();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QLocale_Script);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_script, doc_QLocale_script);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_bcp47Name, "bcp47Name(self) -> str");

extern "C" {static PyObject *meth_QLocale_bcp47Name(PyObject *, PyObject *);}
static PyObject *meth_QLocale_bcp47Name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->bcp47Name());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_bcp47Name, doc_QLocale_bcp47Name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_nativeLanguageName, "nativeLanguageName(self) -> str");

extern "C" {static PyObject *meth_QLocale_nativeLanguageName(PyObject *, PyObject *);}
static PyObject *meth_QLocale_nativeLanguageName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->nativeLanguageName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_nativeLanguageName, doc_QLocale_nativeLanguageName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_nativeCountryName, "nativeCountryName(self) -> str");

extern "C" {static PyObject *meth_QLocale_nativeCountryName(PyObject *, PyObject *);}
static PyObject *meth_QLocale_nativeCountryName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->nativeCountryName());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_nativeCountryName, doc_QLocale_nativeCountryName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_firstDayOfWeek, "firstDayOfWeek(self) -> Qt.DayOfWeek");

extern "C" {static PyObject *meth_QLocale_firstDayOfWeek(PyObject *, PyObject *);}
static PyObject *meth_QLocale_firstDayOfWeek(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::Qt::DayOfWeek sipRes;

            sipRes = sipCpp->firstDayOfWeek();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_DayOfWeek);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_firstDayOfWeek, doc_QLocale_firstDayOfWeek);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_weekdays, "weekdays(self) -> List[Qt.DayOfWeek]");

extern "C" {static PyObject *meth_QLocale_weekdays(PyObject *, PyObject *);}
static PyObject *meth_QLocale_weekdays(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QList<::Qt::DayOfWeek>*sipRes;

            sipRes = new ::QList<::Qt::DayOfWeek>(sipCpp->weekdays());

            return sipConvertFromNewType(sipRes, sipType_QList_0100Qt_DayOfWeek, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_weekdays, doc_QLocale_weekdays);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toUpper, "toUpper(self, str: Optional[str]) -> str");

extern "C" {static PyObject *meth_QLocale_toUpper(PyObject *, PyObject *);}
static PyObject *meth_QLocale_toUpper(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toUpper(*a0));
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toUpper, doc_QLocale_toUpper);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toLower, "toLower(self, str: Optional[str]) -> str");

extern "C" {static PyObject *meth_QLocale_toLower(PyObject *, PyObject *);}
static PyObject *meth_QLocale_toLower(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toLower(*a0));
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toLower, doc_QLocale_toLower);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_currencySymbol, "currencySymbol(self, format: QLocale.CurrencySymbolFormat = QLocale.CurrencySymbol) -> str");

extern "C" {static PyObject *meth_QLocale_currencySymbol(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_currencySymbol(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLocale::CurrencySymbolFormat a0 = QLocale::CurrencySymbol;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|E", &sipSelf, sipType_QLocale, &sipCpp, sipType_QLocale_CurrencySymbolFormat, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->currencySymbol(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_currencySymbol, doc_QLocale_currencySymbol);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toCurrencyString, "toCurrencyString(self, value: float, symbol: Optional[str] = '') -> str\n"
"toCurrencyString(self, value: float, symbol: Optional[str], precision: int) -> str\n"
"toCurrencyString(self, value: int, symbol: Optional[str] = '') -> str");

extern "C" {static PyObject *meth_QLocale_toCurrencyString(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toCurrencyString(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        double a0;
        const ::QString& a1def = QString();
        const ::QString* a1 = &a1def;
        int a1State = 0;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_symbol,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BXd|J1", &sipSelf, sipType_QLocale, &sipCpp, &a0, sipType_QString, &a1, &a1State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toCurrencyString(a0, *a1));
            sipReleaseType(const_cast<::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        double a0;
        const ::QString* a1;
        int a1State = 0;
        int a2;
        const ::QLocale *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, SIP_NULLPTR, "BXdJ1i", &sipSelf, sipType_QLocale, &sipCpp, &a0, sipType_QString, &a1, &a1State, &a2))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->toCurrencyString(a0, *a1, a2));
            sipReleaseType(const_cast<::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    {
        PyObject * a0;
        const ::QString& a1def = QString();
        const ::QString* a1 = &a1def;
        int a1State = 0;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_symbol,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BP0|J1", &sipSelf, sipType_QLocale, &sipCpp, &a0, sipType_QString, &a1, &a1State))
        {
            ::QString*sipRes = 0;
            sipErrorState sipError = sipErrorNone;

#line 1525 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qlocale.sip"
        // Convert a Python int avoiding overflow as much as possible.
        
        static PyObject *zero = 0;
        if (!zero)
            zero = PyLong_FromLong(0);
        
        int rc = PyObject_RichCompareBool(a0, zero, Py_LT);
        
        PyErr_Clear();
        
        if (rc < 0)
        {
            sipError = sipBadCallableArg(0, a0);
        }
        else if (rc)
        {
        #if defined(HAVE_LONG_LONG)
            PY_LONG_LONG value = PyLong_AsLongLong(a0);
        #else
            long value = PyLong_AsLong(a0);
        #endif
        
            if (PyErr_Occurred() && !PyErr_ExceptionMatches(PyExc_OverflowError))
            {
                sipError = sipBadCallableArg(0, a0);
            }
            else
            {
                sipRes = new QString(sipCpp->toCurrencyString(value, *a1));
            }
        }
        else
        {
        #if defined(HAVE_LONG_LONG)
            unsigned PY_LONG_LONG value = PyLong_AsUnsignedLongLongMask(a0);
        #else
            unsigned long value = PyLong_AsUnsignedLongMask(a0);
        #endif
        
            if (PyErr_Occurred() && !PyErr_ExceptionMatches(PyExc_OverflowError))
            {
                sipError = sipBadCallableArg(0, a0);
            }
            else
            {
                sipRes = new QString(sipCpp->toCurrencyString(value, *a1));
            }
        }
#line 2086 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQLocale.cpp"
            sipReleaseType(const_cast<::QString *>(a1), sipType_QString, a1State);

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toCurrencyString, doc_QLocale_toCurrencyString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_uiLanguages, "uiLanguages(self) -> List[str]");

extern "C" {static PyObject *meth_QLocale_uiLanguages(PyObject *, PyObject *);}
static PyObject *meth_QLocale_uiLanguages(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->uiLanguages());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_uiLanguages, doc_QLocale_uiLanguages);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_scriptToString, "scriptToString(script: QLocale.Script) -> str");

extern "C" {static PyObject *meth_QLocale_scriptToString(PyObject *, PyObject *);}
static PyObject *meth_QLocale_scriptToString(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLocale::Script a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "E", sipType_QLocale_Script, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString(::QLocale::scriptToString(a0));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_scriptToString, doc_QLocale_scriptToString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_matchingLocales, "matchingLocales(language: QLocale.Language, script: QLocale.Script, country: QLocale.Country) -> List[QLocale]");

extern "C" {static PyObject *meth_QLocale_matchingLocales(PyObject *, PyObject *);}
static PyObject *meth_QLocale_matchingLocales(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLocale::Language a0;
        ::QLocale::Script a1;
        ::QLocale::Country a2;

        if (sipParseArgs(&sipParseErr, sipArgs, "EEE", sipType_QLocale_Language, &a0, sipType_QLocale_Script, &a1, sipType_QLocale_Country, &a2))
        {
            QList<::QLocale>*sipRes;

            sipRes = new QList<::QLocale>(::QLocale::matchingLocales(a0, a1, a2));

            return sipConvertFromNewType(sipRes, sipType_QList_0100QLocale, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_matchingLocales, doc_QLocale_matchingLocales);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_quoteString, "quoteString(self, str: Optional[str], style: QLocale.QuotationStyle = QLocale.StandardQuotation) -> str");

extern "C" {static PyObject *meth_QLocale_quoteString(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_quoteString(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QLocale::QuotationStyle a1 = QLocale::StandardQuotation;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_style,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|E", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State, sipType_QLocale_QuotationStyle, &a1))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->quoteString(*a0, a1));
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_quoteString, doc_QLocale_quoteString);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_createSeparatedList, "createSeparatedList(self, list: Iterable[Optional[str]]) -> str");

extern "C" {static PyObject *meth_QLocale_createSeparatedList(PyObject *, PyObject *);}
static PyObject *meth_QLocale_createSeparatedList(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStringList* a0;
        int a0State = 0;
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QStringList, &a0, &a0State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->createSeparatedList(*a0));
            sipReleaseType(const_cast<::QStringList *>(a0), sipType_QStringList, a0State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_createSeparatedList, doc_QLocale_createSeparatedList);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_swap, "swap(self, other: QLocale)");

extern "C" {static PyObject *meth_QLocale_swap(PyObject *, PyObject *);}
static PyObject *meth_QLocale_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLocale* a0;
        ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QLocale, &sipCpp, sipType_QLocale, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_swap, doc_QLocale_swap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_formattedDataSize, "formattedDataSize(self, bytes: int, precision: int = 2, format: Union[QLocale.DataSizeFormats, QLocale.DataSizeFormat] = QLocale.DataSizeIecFormat) -> str");

extern "C" {static PyObject *meth_QLocale_formattedDataSize(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_formattedDataSize(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::qint64 a0;
        int a1 = 2;
        ::QLocale::DataSizeFormats a2def = QLocale::DataSizeIecFormat;
        ::QLocale::DataSizeFormats* a2 = &a2def;
        int a2State = 0;
        ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_precision,
            sipName_format,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bn|iJ1", &sipSelf, sipType_QLocale, &sipCpp, &a0, &a1, sipType_QLocale_DataSizeFormats, &a2, &a2State))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->formattedDataSize(a0, a1, *a2));
            sipReleaseType(a2, sipType_QLocale_DataSizeFormats, a2State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_formattedDataSize, doc_QLocale_formattedDataSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toLong, "toLong(self, s: Optional[str]) -> (int, Optional[bool])");

extern "C" {static PyObject *meth_QLocale_toLong(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toLong(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        bool a1;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State))
        {
            long sipRes;

            sipRes = sipCpp->toLong(*a0, &a1);
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            return sipBuildResult(0, "(lb)", sipRes, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toLong, doc_QLocale_toLong);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_toULong, "toULong(self, s: Optional[str]) -> (int, Optional[bool])");

extern "C" {static PyObject *meth_QLocale_toULong(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QLocale_toULong(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        bool a1;
        const ::QLocale *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1", &sipSelf, sipType_QLocale, &sipCpp, sipType_QString, &a0, &a0State))
        {
            ::ulong sipRes;

            sipRes = sipCpp->toULong(*a0, &a1);
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            return sipBuildResult(0, "(mb)", sipRes, a1);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_toULong, doc_QLocale_toULong);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QLocale_collation, "collation(self) -> QLocale");

extern "C" {static PyObject *meth_QLocale_collation(PyObject *, PyObject *);}
static PyObject *meth_QLocale_collation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QLocale, &sipCpp))
        {
            ::QLocale*sipRes;

            sipRes = new ::QLocale(sipCpp->collation());

            return sipConvertFromNewType(sipRes, sipType_QLocale, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QLocale, sipName_collation, doc_QLocale_collation);

    return SIP_NULLPTR;
}


extern "C" {static long slot_QLocale___hash__(PyObject *);}
static long slot_QLocale___hash__(PyObject *sipSelf)
{
    ::QLocale *sipCpp = reinterpret_cast<::QLocale *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QLocale));

    if (!sipCpp)
        return 0L;


    {
        {
            long sipRes = 0;

#line 1448 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qlocale.sip"
        sipRes = qHash(*sipCpp);
#line 2424 "/usr/src/debug/python3-pyqt5/5.15.10/QtCore/sipQtCoreQLocale.cpp"

            return sipRes;
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_QLocale___ne__(PyObject *, PyObject *);}
static PyObject *slot_QLocale___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QLocale *sipCpp = reinterpret_cast<::QLocale *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QLocale));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QLocale, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QLocale::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, ne_slot, sipType_QLocale, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QLocale___eq__(PyObject *, PyObject *);}
static PyObject *slot_QLocale___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QLocale *sipCpp = reinterpret_cast<::QLocale *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QLocale));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QLocale, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->::QLocale::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtCore, eq_slot, sipType_QLocale, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QLocale(void *, int);}
static void release_QLocale(void *sipCppV, int)
{
    delete reinterpret_cast<::QLocale *>(sipCppV);
}


extern "C" {static void *array_QLocale(Py_ssize_t);}
static void *array_QLocale(Py_ssize_t sipNrElem)
{
    return new ::QLocale[sipNrElem];
}


extern "C" {static void array_delete_QLocale(void *);}
static void array_delete_QLocale(void *sipCpp)
{
    delete[] reinterpret_cast<::QLocale *>(sipCpp);
}


extern "C" {static void assign_QLocale(void *, Py_ssize_t, void *);}
static void assign_QLocale(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast<::QLocale *>(sipDst)[sipDstIdx] = *reinterpret_cast<::QLocale *>(sipSrc);
}


extern "C" {static void *copy_QLocale(const void *, Py_ssize_t);}
static void *copy_QLocale(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QLocale(reinterpret_cast<const ::QLocale *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QLocale(sipSimpleWrapper *);}
static void dealloc_QLocale(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QLocale(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QLocale(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QLocale(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QLocale *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QLocale();

            return sipCpp;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1", sipType_QString, &a0, &a0State))
        {
            sipCpp = new ::QLocale(*a0);
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            return sipCpp;
        }
    }

    {
        ::QLocale::Language a0;
        ::QLocale::Country a1 = QLocale::AnyCountry;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_country,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "E|E", sipType_QLocale_Language, &a0, sipType_QLocale_Country, &a1))
        {
            sipCpp = new ::QLocale(a0, a1);

            return sipCpp;
        }
    }

    {
        const ::QLocale* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QLocale, &a0))
        {
            sipCpp = new ::QLocale(*a0);

            return sipCpp;
        }
    }

    {
        ::QLocale::Language a0;
        ::QLocale::Script a1;
        ::QLocale::Country a2;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "EEE", sipType_QLocale_Language, &a0, sipType_QLocale_Script, &a1, sipType_QLocale_Country, &a2))
        {
            sipCpp = new ::QLocale(a0, a1, a2);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QLocale[] = {
    {(void *)slot_QLocale___hash__, hash_slot},
    {(void *)slot_QLocale___ne__, ne_slot},
    {(void *)slot_QLocale___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QLocale[] = {
    {sipName_amText, meth_QLocale_amText, METH_VARARGS, doc_QLocale_amText},
    {sipName_bcp47Name, meth_QLocale_bcp47Name, METH_VARARGS, doc_QLocale_bcp47Name},
    {sipName_c, meth_QLocale_c, METH_VARARGS, doc_QLocale_c},
    {sipName_collation, meth_QLocale_collation, METH_VARARGS, doc_QLocale_collation},
    {sipName_country, meth_QLocale_country, METH_VARARGS, doc_QLocale_country},
    {sipName_countryToString, meth_QLocale_countryToString, METH_VARARGS, doc_QLocale_countryToString},
    {sipName_createSeparatedList, meth_QLocale_createSeparatedList, METH_VARARGS, doc_QLocale_createSeparatedList},
    {sipName_currencySymbol, SIP_MLMETH_CAST(meth_QLocale_currencySymbol), METH_VARARGS|METH_KEYWORDS, doc_QLocale_currencySymbol},
    {sipName_dateFormat, SIP_MLMETH_CAST(meth_QLocale_dateFormat), METH_VARARGS|METH_KEYWORDS, doc_QLocale_dateFormat},
    {sipName_dateTimeFormat, SIP_MLMETH_CAST(meth_QLocale_dateTimeFormat), METH_VARARGS|METH_KEYWORDS, doc_QLocale_dateTimeFormat},
    {sipName_dayName, SIP_MLMETH_CAST(meth_QLocale_dayName), METH_VARARGS|METH_KEYWORDS, doc_QLocale_dayName},
    {sipName_decimalPoint, meth_QLocale_decimalPoint, METH_VARARGS, doc_QLocale_decimalPoint},
    {sipName_exponential, meth_QLocale_exponential, METH_VARARGS, doc_QLocale_exponential},
    {sipName_firstDayOfWeek, meth_QLocale_firstDayOfWeek, METH_VARARGS, doc_QLocale_firstDayOfWeek},
    {sipName_formattedDataSize, SIP_MLMETH_CAST(meth_QLocale_formattedDataSize), METH_VARARGS|METH_KEYWORDS, doc_QLocale_formattedDataSize},
    {sipName_groupSeparator, meth_QLocale_groupSeparator, METH_VARARGS, doc_QLocale_groupSeparator},
    {sipName_language, meth_QLocale_language, METH_VARARGS, doc_QLocale_language},
    {sipName_languageToString, meth_QLocale_languageToString, METH_VARARGS, doc_QLocale_languageToString},
    {sipName_matchingLocales, meth_QLocale_matchingLocales, METH_VARARGS, doc_QLocale_matchingLocales},
    {sipName_measurementSystem, meth_QLocale_measurementSystem, METH_VARARGS, doc_QLocale_measurementSystem},
    {sipName_monthName, SIP_MLMETH_CAST(meth_QLocale_monthName), METH_VARARGS|METH_KEYWORDS, doc_QLocale_monthName},
    {sipName_name, meth_QLocale_name, METH_VARARGS, doc_QLocale_name},
    {sipName_nativeCountryName, meth_QLocale_nativeCountryName, METH_VARARGS, doc_QLocale_nativeCountryName},
    {sipName_nativeLanguageName, meth_QLocale_nativeLanguageName, METH_VARARGS, doc_QLocale_nativeLanguageName},
    {sipName_negativeSign, meth_QLocale_negativeSign, METH_VARARGS, doc_QLocale_negativeSign},
    {sipName_numberOptions, meth_QLocale_numberOptions, METH_VARARGS, doc_QLocale_numberOptions},
    {sipName_percent, meth_QLocale_percent, METH_VARARGS, doc_QLocale_percent},
    {sipName_pmText, meth_QLocale_pmText, METH_VARARGS, doc_QLocale_pmText},
    {sipName_positiveSign, meth_QLocale_positiveSign, METH_VARARGS, doc_QLocale_positiveSign},
    {sipName_quoteString, SIP_MLMETH_CAST(meth_QLocale_quoteString), METH_VARARGS|METH_KEYWORDS, doc_QLocale_quoteString},
    {sipName_script, meth_QLocale_script, METH_VARARGS, doc_QLocale_script},
    {sipName_scriptToString, meth_QLocale_scriptToString, METH_VARARGS, doc_QLocale_scriptToString},
    {sipName_setDefault, meth_QLocale_setDefault, METH_VARARGS, doc_QLocale_setDefault},
    {sipName_setNumberOptions, meth_QLocale_setNumberOptions, METH_VARARGS, doc_QLocale_setNumberOptions},
    {sipName_standaloneDayName, SIP_MLMETH_CAST(meth_QLocale_standaloneDayName), METH_VARARGS|METH_KEYWORDS, doc_QLocale_standaloneDayName},
    {sipName_standaloneMonthName, SIP_MLMETH_CAST(meth_QLocale_standaloneMonthName), METH_VARARGS|METH_KEYWORDS, doc_QLocale_standaloneMonthName},
    {sipName_swap, meth_QLocale_swap, METH_VARARGS, doc_QLocale_swap},
    {sipName_system, meth_QLocale_system, METH_VARARGS, doc_QLocale_system},
    {sipName_textDirection, meth_QLocale_textDirection, METH_VARARGS, doc_QLocale_textDirection},
    {sipName_timeFormat, SIP_MLMETH_CAST(meth_QLocale_timeFormat), METH_VARARGS|METH_KEYWORDS, doc_QLocale_timeFormat},
    {sipName_toCurrencyString, SIP_MLMETH_CAST(meth_QLocale_toCurrencyString), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toCurrencyString},
    {sipName_toDate, SIP_MLMETH_CAST(meth_QLocale_toDate), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toDate},
    {sipName_toDateTime, SIP_MLMETH_CAST(meth_QLocale_toDateTime), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toDateTime},
    {sipName_toDouble, SIP_MLMETH_CAST(meth_QLocale_toDouble), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toDouble},
    {sipName_toFloat, SIP_MLMETH_CAST(meth_QLocale_toFloat), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toFloat},
    {sipName_toInt, SIP_MLMETH_CAST(meth_QLocale_toInt), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toInt},
    {sipName_toLong, SIP_MLMETH_CAST(meth_QLocale_toLong), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toLong},
    {sipName_toLongLong, SIP_MLMETH_CAST(meth_QLocale_toLongLong), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toLongLong},
    {sipName_toLower, meth_QLocale_toLower, METH_VARARGS, doc_QLocale_toLower},
    {sipName_toShort, SIP_MLMETH_CAST(meth_QLocale_toShort), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toShort},
    {sipName_toString, SIP_MLMETH_CAST(meth_QLocale_toString), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toString},
    {sipName_toTime, SIP_MLMETH_CAST(meth_QLocale_toTime), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toTime},
    {sipName_toUInt, SIP_MLMETH_CAST(meth_QLocale_toUInt), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toUInt},
    {sipName_toULong, SIP_MLMETH_CAST(meth_QLocale_toULong), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toULong},
    {sipName_toULongLong, SIP_MLMETH_CAST(meth_QLocale_toULongLong), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toULongLong},
    {sipName_toUShort, SIP_MLMETH_CAST(meth_QLocale_toUShort), METH_VARARGS|METH_KEYWORDS, doc_QLocale_toUShort},
    {sipName_toUpper, meth_QLocale_toUpper, METH_VARARGS, doc_QLocale_toUpper},
    {sipName_uiLanguages, meth_QLocale_uiLanguages, METH_VARARGS, doc_QLocale_uiLanguages},
    {sipName_weekdays, meth_QLocale_weekdays, METH_VARARGS, doc_QLocale_weekdays},
    {sipName_zeroDigit, meth_QLocale_zeroDigit, METH_VARARGS, doc_QLocale_zeroDigit}
};

static sipEnumMemberDef enummembers_QLocale[] = {
    {sipName_Abkhazian, static_cast<int>(::QLocale::Abkhazian), 156},
    {sipName_AdlamScript, static_cast<int>(::QLocale::AdlamScript), 161},
    {sipName_Afan, static_cast<int>(::QLocale::Afan), 156},
    {sipName_Afar, static_cast<int>(::QLocale::Afar), 156},
    {sipName_Afghanistan, static_cast<int>(::QLocale::Afghanistan), 150},
    {sipName_Afrikaans, static_cast<int>(::QLocale::Afrikaans), 156},
    {sipName_Aghem, static_cast<int>(::QLocale::Aghem), 156},
    {sipName_Ahom, static_cast<int>(::QLocale::Ahom), 156},
    {sipName_AhomScript, static_cast<int>(::QLocale::AhomScript), 161},
    {sipName_Akan, static_cast<int>(::QLocale::Akan), 156},
    {sipName_Akkadian, static_cast<int>(::QLocale::Akkadian), 156},
    {sipName_Akoose, static_cast<int>(::QLocale::Akoose), 156},
    {sipName_AlandIslands, static_cast<int>(::QLocale::AlandIslands), 150},
    {sipName_Albania, static_cast<int>(::QLocale::Albania), 150},
    {sipName_Albanian, static_cast<int>(::QLocale::Albanian), 156},
    {sipName_Algeria, static_cast<int>(::QLocale::Algeria), 150},
    {sipName_AlternateQuotation, static_cast<int>(::QLocale::AlternateQuotation), 160},
    {sipName_AmericanSamoa, static_cast<int>(::QLocale::AmericanSamoa), 150},
    {sipName_AmericanSignLanguage, static_cast<int>(::QLocale::AmericanSignLanguage), 156},
    {sipName_Amharic, static_cast<int>(::QLocale::Amharic), 156},
    {sipName_AnatolianHieroglyphsScript, static_cast<int>(::QLocale::AnatolianHieroglyphsScript), 161},
    {sipName_AncientEgyptian, static_cast<int>(::QLocale::AncientEgyptian), 156},
    {sipName_AncientGreek, static_cast<int>(::QLocale::AncientGreek), 156},
    {sipName_AncientNorthArabian, static_cast<int>(::QLocale::AncientNorthArabian), 156},
    {sipName_Andorra, static_cast<int>(::QLocale::Andorra), 150},
    {sipName_Angola, static_cast<int>(::QLocale::Angola), 150},
    {sipName_Anguilla, static_cast<int>(::QLocale::Anguilla), 150},
    {sipName_Antarctica, static_cast<int>(::QLocale::Antarctica), 150},
    {sipName_AntiguaAndBarbuda, static_cast<int>(::QLocale::AntiguaAndBarbuda), 150},
    {sipName_AnyCountry, static_cast<int>(::QLocale::AnyCountry), 150},
    {sipName_AnyLanguage, static_cast<int>(::QLocale::AnyLanguage), 156},
    {sipName_AnyScript, static_cast<int>(::QLocale::AnyScript), 161},
    {sipName_Arabic, static_cast<int>(::QLocale::Arabic), 156},
    {sipName_ArabicScript, static_cast<int>(::QLocale::ArabicScript), 161},
    {sipName_Aragonese, static_cast<int>(::QLocale::Aragonese), 156},
    {sipName_Aramaic, static_cast<int>(::QLocale::Aramaic), 156},
    {sipName_ArdhamagadhiPrakrit, static_cast<int>(::QLocale::ArdhamagadhiPrakrit), 156},
    {sipName_Argentina, static_cast<int>(::QLocale::Argentina), 150},
    {sipName_Armenia, static_cast<int>(::QLocale::Armenia), 150},
    {sipName_Armenian, static_cast<int>(::QLocale::Armenian), 156},
    {sipName_ArmenianScript, static_cast<int>(::QLocale::ArmenianScript), 161},
    {sipName_Aruba, static_cast<int>(::QLocale::Aruba), 150},
    {sipName_AscensionIsland, static_cast<int>(::QLocale::AscensionIsland), 150},
    {sipName_Assamese, static_cast<int>(::QLocale::Assamese), 156},
    {sipName_Asturian, static_cast<int>(::QLocale::Asturian), 156},
    {sipName_Asu, static_cast<int>(::QLocale::Asu), 156},
    {sipName_Atsam, static_cast<int>(::QLocale::Atsam), 156},
    {sipName_Australia, static_cast<int>(::QLocale::Australia), 150},
    {sipName_Austria, static_cast<int>(::QLocale::Austria), 150},
    {sipName_Avaric, static_cast<int>(::QLocale::Avaric), 156},
    {sipName_Avestan, static_cast<int>(::QLocale::Avestan), 156},
    {sipName_AvestanScript, static_cast<int>(::QLocale::AvestanScript), 161},
    {sipName_Aymara, static_cast<int>(::QLocale::Aymara), 156},
    {sipName_Azerbaijan, static_cast<int>(::QLocale::Azerbaijan), 150},
    {sipName_Azerbaijani, static_cast<int>(::QLocale::Azerbaijani), 156},
    {sipName_Bafia, static_cast<int>(::QLocale::Bafia), 156},
    {sipName_Bahamas, static_cast<int>(::QLocale::Bahamas), 150},
    {sipName_Bahrain, static_cast<int>(::QLocale::Bahrain), 150},
    {sipName_Balinese, static_cast<int>(::QLocale::Balinese), 156},
    {sipName_BalineseScript, static_cast<int>(::QLocale::BalineseScript), 161},
    {sipName_Bambara, static_cast<int>(::QLocale::Bambara), 156},
    {sipName_BamumScript, static_cast<int>(::QLocale::BamumScript), 161},
    {sipName_Bamun, static_cast<int>(::QLocale::Bamun), 156},
    {sipName_Bangladesh, static_cast<int>(::QLocale::Bangladesh), 150},
    {sipName_Barbados, static_cast<int>(::QLocale::Barbados), 150},
    {sipName_Basaa, static_cast<int>(::QLocale::Basaa), 156},
    {sipName_Bashkir, static_cast<int>(::QLocale::Bashkir), 156},
    {sipName_Basque, static_cast<int>(::QLocale::Basque), 156},
    {sipName_Bassa, static_cast<int>(::QLocale::Bassa), 156},
    {sipName_BassaVahScript, static_cast<int>(::QLocale::BassaVahScript), 161},
    {sipName_BatakScript, static_cast<int>(::QLocale::BatakScript), 161},
    {sipName_BatakToba, static_cast<int>(::QLocale::BatakToba), 156},
    {sipName_Belarus, static_cast<int>(::QLocale::Belarus), 150},
    {sipName_Belarusian, static_cast<int>(::QLocale::Belarusian), 156},
    {sipName_Belgium, static_cast<int>(::QLocale::Belgium), 150},
    {sipName_Belize, static_cast<int>(::QLocale::Belize), 150},
    {sipName_Bemba, static_cast<int>(::QLocale::Bemba), 156},
    {sipName_Bena, static_cast<int>(::QLocale::Bena), 156},
    {sipName_Bengali, static_cast<int>(::QLocale::Bengali), 156},
    {sipName_BengaliScript, static_cast<int>(::QLocale::BengaliScript), 161},
    {sipName_Benin, static_cast<int>(::QLocale::Benin), 150},
    {sipName_Bermuda, static_cast<int>(::QLocale::Bermuda), 150},
    {sipName_BhaiksukiScript, static_cast<int>(::QLocale::BhaiksukiScript), 161},
    {sipName_Bhojpuri, static_cast<int>(::QLocale::Bhojpuri), 156},
    {sipName_Bhutan, static_cast<int>(::QLocale::Bhutan), 150},
    {sipName_Bhutani, static_cast<int>(::QLocale::Bhutani), 156},
    {sipName_Bihari, static_cast<int>(::QLocale::Bihari), 156},
    {sipName_Bislama, static_cast<int>(::QLocale::Bislama), 156},
    {sipName_Blin, static_cast<int>(::QLocale::Blin), 156},
    {sipName_Bodo, static_cast<int>(::QLocale::Bodo), 156},
    {sipName_Bolivia, static_cast<int>(::QLocale::Bolivia), 150},
    {sipName_Bonaire, static_cast<int>(::QLocale::Bonaire), 150},
    {sipName_BopomofoScript, static_cast<int>(::QLocale::BopomofoScript), 161},
    {sipName_BosniaAndHerzegowina, static_cast<int>(::QLocale::BosniaAndHerzegowina), 150},
    {sipName_Bosnian, static_cast<int>(::QLocale::Bosnian), 156},
    {sipName_Botswana, static_cast<int>(::QLocale::Botswana), 150},
    {sipName_BouvetIsland, static_cast<int>(::QLocale::BouvetIsland), 150},
    {sipName_BrahmiScript, static_cast<int>(::QLocale::BrahmiScript), 161},
    {sipName_BrailleScript, static_cast<int>(::QLocale::BrailleScript), 161},
    {sipName_Brazil, static_cast<int>(::QLocale::Brazil), 150},
    {sipName_Breton, static_cast<int>(::QLocale::Breton), 156},
    {sipName_BritishIndianOceanTerritory, static_cast<int>(::QLocale::BritishIndianOceanTerritory), 150},
    {sipName_BritishVirginIslands, static_cast<int>(::QLocale::BritishVirginIslands), 150},
    {sipName_Brunei, static_cast<int>(::QLocale::Brunei), 150},
    {sipName_Buginese, static_cast<int>(::QLocale::Buginese), 156},
    {sipName_BugineseScript, static_cast<int>(::QLocale::BugineseScript), 161},
    {sipName_Buhid, static_cast<int>(::QLocale::Buhid), 156},
    {sipName_BuhidScript, static_cast<int>(::QLocale::BuhidScript), 161},
    {sipName_Bulgaria, static_cast<int>(::QLocale::Bulgaria), 150},
    {sipName_Bulgarian, static_cast<int>(::QLocale::Bulgarian), 156},
    {sipName_BurkinaFaso, static_cast<int>(::QLocale::BurkinaFaso), 150},
    {sipName_Burmese, static_cast<int>(::QLocale::Burmese), 156},
    {sipName_Burundi, static_cast<int>(::QLocale::Burundi), 150},
    {sipName_Byelorussian, static_cast<int>(::QLocale::Byelorussian), 156},
    {sipName_C, static_cast<int>(::QLocale::C), 156},
    {sipName_Cambodia, static_cast<int>(::QLocale::Cambodia), 150},
    {sipName_Cambodian, static_cast<int>(::QLocale::Cambodian), 156},
    {sipName_Cameroon, static_cast<int>(::QLocale::Cameroon), 150},
    {sipName_Canada, static_cast<int>(::QLocale::Canada), 150},
    {sipName_CanadianAboriginalScript, static_cast<int>(::QLocale::CanadianAboriginalScript), 161},
    {sipName_CanaryIslands, static_cast<int>(::QLocale::CanaryIslands), 150},
    {sipName_Cantonese, static_cast<int>(::QLocale::Cantonese), 156},
    {sipName_CapeVerde, static_cast<int>(::QLocale::CapeVerde), 150},
    {sipName_Carian, static_cast<int>(::QLocale::Carian), 156},
    {sipName_CarianScript, static_cast<int>(::QLocale::CarianScript), 161},
    {sipName_Catalan, static_cast<int>(::QLocale::Catalan), 156},
    {sipName_CaucasianAlbanianScript, static_cast<int>(::QLocale::CaucasianAlbanianScript), 161},
    {sipName_CaymanIslands, static_cast<int>(::QLocale::CaymanIslands), 150},
    {sipName_Cebuano, static_cast<int>(::QLocale::Cebuano), 156},
    {sipName_CentralAfricanRepublic, static_cast<int>(::QLocale::CentralAfricanRepublic), 150},
    {sipName_CentralKurdish, static_cast<int>(::QLocale::CentralKurdish), 156},
    {sipName_CentralMoroccoTamazight, static_cast<int>(::QLocale::CentralMoroccoTamazight), 156},
    {sipName_CeutaAndMelilla, static_cast<int>(::QLocale::CeutaAndMelilla), 150},
    {sipName_Chad, static_cast<int>(::QLocale::Chad), 150},
    {sipName_Chakma, static_cast<int>(::QLocale::Chakma), 156},
    {sipName_ChakmaScript, static_cast<int>(::QLocale::ChakmaScript), 161},
    {sipName_ChamScript, static_cast<int>(::QLocale::ChamScript), 161},
    {sipName_Chamorro, static_cast<int>(::QLocale::Chamorro), 156},
    {sipName_Chechen, static_cast<int>(::QLocale::Chechen), 156},
    {sipName_Cherokee, static_cast<int>(::QLocale::Cherokee), 156},
    {sipName_CherokeeScript, static_cast<int>(::QLocale::CherokeeScript), 161},
    {sipName_Chewa, static_cast<int>(::QLocale::Chewa), 156},
    {sipName_Chickasaw, static_cast<int>(::QLocale::Chickasaw), 156},
    {sipName_Chiga, static_cast<int>(::QLocale::Chiga), 156},
    {sipName_Chile, static_cast<int>(::QLocale::Chile), 150},
    {sipName_China, static_cast<int>(::QLocale::China), 150},
    {sipName_Chinese, static_cast<int>(::QLocale::Chinese), 156},
    {sipName_ChristmasIsland, static_cast<int>(::QLocale::ChristmasIsland), 150},
    {sipName_Church, static_cast<int>(::QLocale::Church), 156},
    {sipName_Chuvash, static_cast<int>(::QLocale::Chuvash), 156},
    {sipName_ClassicalMandaic, static_cast<int>(::QLocale::ClassicalMandaic), 156},
    {sipName_ClippertonIsland, static_cast<int>(::QLocale::ClippertonIsland), 150},
    {sipName_CocosIslands, static_cast<int>(::QLocale::CocosIslands), 150},
    {sipName_Colognian, static_cast<int>(::QLocale::Colognian), 156},
    {sipName_Colombia, static_cast<int>(::QLocale::Colombia), 150},
    {sipName_Comoros, static_cast<int>(::QLocale::Comoros), 150},
    {sipName_CongoBrazzaville, static_cast<int>(::QLocale::CongoBrazzaville), 150},
    {sipName_CongoKinshasa, static_cast<int>(::QLocale::CongoKinshasa), 150},
    {sipName_CongoSwahili, static_cast<int>(::QLocale::CongoSwahili), 156},
    {sipName_CookIslands, static_cast<int>(::QLocale::CookIslands), 150},
    {sipName_Coptic, static_cast<int>(::QLocale::Coptic), 156},
    {sipName_CopticScript, static_cast<int>(::QLocale::CopticScript), 161},
    {sipName_Cornish, static_cast<int>(::QLocale::Cornish), 156},
    {sipName_Corsican, static_cast<int>(::QLocale::Corsican), 156},
    {sipName_CostaRica, static_cast<int>(::QLocale::CostaRica), 150},
    {sipName_Cree, static_cast<int>(::QLocale::Cree), 156},
    {sipName_Croatia, static_cast<int>(::QLocale::Croatia), 150},
    {sipName_Croatian, static_cast<int>(::QLocale::Croatian), 156},
    {sipName_Cuba, static_cast<int>(::QLocale::Cuba), 150},
    {sipName_CuneiformScript, static_cast<int>(::QLocale::CuneiformScript), 161},
    {sipName_CuraSao, static_cast<int>(::QLocale::CuraSao), 150},
    {sipName_CurrencyDisplayName, static_cast<int>(::QLocale::CurrencyDisplayName), 151},
    {sipName_CurrencyIsoCode, static_cast<int>(::QLocale::CurrencyIsoCode), 151},
    {sipName_CurrencySymbol, static_cast<int>(::QLocale::CurrencySymbol), 151},
    {sipName_CypriotScript, static_cast<int>(::QLocale::CypriotScript), 161},
    {sipName_Cyprus, static_cast<int>(::QLocale::Cyprus), 150},
    {sipName_CyrillicScript, static_cast<int>(::QLocale::CyrillicScript), 161},
    {sipName_Czech, static_cast<int>(::QLocale::Czech), 156},
    {sipName_CzechRepublic, static_cast<int>(::QLocale::CzechRepublic), 150},
    {sipName_Danish, static_cast<int>(::QLocale::Danish), 156},
    {sipName_DataSizeIecFormat, static_cast<int>(::QLocale::DataSizeIecFormat), 152},
    {sipName_DataSizeSIFormat, static_cast<int>(::QLocale::DataSizeSIFormat), 152},
    {sipName_DataSizeTraditionalFormat, static_cast<int>(::QLocale::DataSizeTraditionalFormat), 152},
    {sipName_DefaultNumberOptions, static_cast<int>(::QLocale::DefaultNumberOptions), 158},
    {sipName_DemocraticRepublicOfCongo, static_cast<int>(::QLocale::DemocraticRepublicOfCongo), 150},
    {sipName_DemocraticRepublicOfKorea, static_cast<int>(::QLocale::DemocraticRepublicOfKorea), 150},
    {sipName_Denmark, static_cast<int>(::QLocale::Denmark), 150},
    {sipName_DeseretScript, static_cast<int>(::QLocale::DeseretScript), 161},
    {sipName_DevanagariScript, static_cast<int>(::QLocale::DevanagariScript), 161},
    {sipName_DiegoGarcia, static_cast<int>(::QLocale::DiegoGarcia), 150},
    {sipName_Divehi, static_cast<int>(::QLocale::Divehi), 156},
    {sipName_Djibouti, static_cast<int>(::QLocale::Djibouti), 150},
    {sipName_Dogri, static_cast<int>(::QLocale::Dogri), 156},
    {sipName_Dominica, static_cast<int>(::QLocale::Dominica), 150},
    {sipName_DominicanRepublic, static_cast<int>(::QLocale::DominicanRepublic), 150},
    {sipName_Duala, static_cast<int>(::QLocale::Duala), 156},
    {sipName_DuployanScript, static_cast<int>(::QLocale::DuployanScript), 161},
    {sipName_Dutch, static_cast<int>(::QLocale::Dutch), 156},
    {sipName_Dzongkha, static_cast<int>(::QLocale::Dzongkha), 156},
    {sipName_EastTimor, static_cast<int>(::QLocale::EastTimor), 150},
    {sipName_EasternCham, static_cast<int>(::QLocale::EasternCham), 156},
    {sipName_EasternKayah, static_cast<int>(::QLocale::EasternKayah), 156},
    {sipName_Ecuador, static_cast<int>(::QLocale::Ecuador), 150},
    {sipName_Egypt, static_cast<int>(::QLocale::Egypt), 150},
    {sipName_EgyptianHieroglyphsScript, static_cast<int>(::QLocale::EgyptianHieroglyphsScript), 161},
    {sipName_ElSalvador, static_cast<int>(::QLocale::ElSalvador), 150},
    {sipName_ElbasanScript, static_cast<int>(::QLocale::ElbasanScript), 161},
    {sipName_Embu, static_cast<int>(::QLocale::Embu), 156},
    {sipName_English, static_cast<int>(::QLocale::English), 156},
    {sipName_EquatorialGuinea, static_cast<int>(::QLocale::EquatorialGuinea), 150},
    {sipName_Eritrea, static_cast<int>(::QLocale::Eritrea), 150},
    {sipName_Erzya, static_cast<int>(::QLocale::Erzya), 156},
    {sipName_Esperanto, static_cast<int>(::QLocale::Esperanto), 156},
    {sipName_Estonia, static_cast<int>(::QLocale::Estonia), 150},
    {sipName_Estonian, static_cast<int>(::QLocale::Estonian), 156},
    {sipName_Ethiopia, static_cast<int>(::QLocale::Ethiopia), 150},
    {sipName_EthiopicScript, static_cast<int>(::QLocale::EthiopicScript), 161},
    {sipName_Etruscan, static_cast<int>(::QLocale::Etruscan), 156},
    {sipName_Europe, static_cast<int>(::QLocale::Europe), 150},
    {sipName_EuropeanUnion, static_cast<int>(::QLocale::EuropeanUnion), 150},
    {sipName_Ewe, static_cast<int>(::QLocale::Ewe), 156},
    {sipName_Ewondo, static_cast<int>(::QLocale::Ewondo), 156},
    {sipName_FalklandIslands, static_cast<int>(::QLocale::FalklandIslands), 150},
    {sipName_FaroeIslands, static_cast<int>(::QLocale::FaroeIslands), 150},
    {sipName_Faroese, static_cast<int>(::QLocale::Faroese), 156},
    {sipName_Fiji, static_cast<int>(::QLocale::Fiji), 150},
    {sipName_Fijian, static_cast<int>(::QLocale::Fijian), 156},
    {sipName_Filipino, static_cast<int>(::QLocale::Filipino), 156},
    {sipName_Finland, static_cast<int>(::QLocale::Finland), 150},
    {sipName_Finnish, static_cast<int>(::QLocale::Finnish), 156},
    {sipName_FloatingPointShortest, static_cast<int>(::QLocale::FloatingPointShortest), 154},
    {sipName_France, static_cast<int>(::QLocale::France), 150},
    {sipName_FraserScript, static_cast<int>(::QLocale::FraserScript), 161},
    {sipName_French, static_cast<int>(::QLocale::French), 156},
    {sipName_FrenchGuiana, static_cast<int>(::QLocale::FrenchGuiana), 150},
    {sipName_FrenchPolynesia, static_cast<int>(::QLocale::FrenchPolynesia), 150},
    {sipName_FrenchSouthernTerritories, static_cast<int>(::QLocale::FrenchSouthernTerritories), 150},
    {sipName_Frisian, static_cast<int>(::QLocale::Frisian), 156},
    {sipName_Friulian, static_cast<int>(::QLocale::Friulian), 156},
    {sipName_Fulah, static_cast<int>(::QLocale::Fulah), 156},
    {sipName_Ga, static_cast<int>(::QLocale::Ga), 156},
    {sipName_Gabon, static_cast<int>(::QLocale::Gabon), 150},
    {sipName_Gaelic, static_cast<int>(::QLocale::Gaelic), 156},
    {sipName_Galician, static_cast<int>(::QLocale::Galician), 156},
    {sipName_Gambia, static_cast<int>(::QLocale::Gambia), 150},
    {sipName_Ganda, static_cast<int>(::QLocale::Ganda), 156},
    {sipName_Geez, static_cast<int>(::QLocale::Geez), 156},
    {sipName_Georgia, static_cast<int>(::QLocale::Georgia), 150},
    {sipName_Georgian, static_cast<int>(::QLocale::Georgian), 156},
    {sipName_GeorgianScript, static_cast<int>(::QLocale::GeorgianScript), 161},
    {sipName_German, static_cast<int>(::QLocale::German), 156},
    {sipName_Germany, static_cast<int>(::QLocale::Germany), 150},
    {sipName_Ghana, static_cast<int>(::QLocale::Ghana), 150},
    {sipName_Gibraltar, static_cast<int>(::QLocale::Gibraltar), 150},
    {sipName_GlagoliticScript, static_cast<int>(::QLocale::GlagoliticScript), 161},
    {sipName_Gothic, static_cast<int>(::QLocale::Gothic), 156},
    {sipName_GothicScript, static_cast<int>(::QLocale::GothicScript), 161},
    {sipName_GranthaScript, static_cast<int>(::QLocale::GranthaScript), 161},
    {sipName_Greece, static_cast<int>(::QLocale::Greece), 150},
    {sipName_Greek, static_cast<int>(::QLocale::Greek), 156},
    {sipName_GreekScript, static_cast<int>(::QLocale::GreekScript), 161},
    {sipName_Greenland, static_cast<int>(::QLocale::Greenland), 150},
    {sipName_Greenlandic, static_cast<int>(::QLocale::Greenlandic), 156},
    {sipName_Grenada, static_cast<int>(::QLocale::Grenada), 150},
    {sipName_Guadeloupe, static_cast<int>(::QLocale::Guadeloupe), 150},
    {sipName_Guam, static_cast<int>(::QLocale::Guam), 150},
    {sipName_Guarani, static_cast<int>(::QLocale::Guarani), 156},
    {sipName_Guatemala, static_cast<int>(::QLocale::Guatemala), 150},
    {sipName_Guernsey, static_cast<int>(::QLocale::Guernsey), 150},
    {sipName_Guinea, static_cast<int>(::QLocale::Guinea), 150},
    {sipName_GuineaBissau, static_cast<int>(::QLocale::GuineaBissau), 150},
    {sipName_Gujarati, static_cast<int>(::QLocale::Gujarati), 156},
    {sipName_GujaratiScript, static_cast<int>(::QLocale::GujaratiScript), 161},
    {sipName_GurmukhiScript, static_cast<int>(::QLocale::GurmukhiScript), 161},
    {sipName_Gusii, static_cast<int>(::QLocale::Gusii), 156},
    {sipName_Guyana, static_cast<int>(::QLocale::Guyana), 150},
    {sipName_Haiti, static_cast<int>(::QLocale::Haiti), 150},
    {sipName_Haitian, static_cast<int>(::QLocale::Haitian), 156},
    {sipName_HanScript, static_cast<int>(::QLocale::HanScript), 161},
    {sipName_HanWithBopomofoScript, static_cast<int>(::QLocale::HanWithBopomofoScript), 161},
    {sipName_HangulScript, static_cast<int>(::QLocale::HangulScript), 161},
    {sipName_Hanunoo, static_cast<int>(::QLocale::Hanunoo), 156},
    {sipName_HanunooScript, static_cast<int>(::QLocale::HanunooScript), 161},
    {sipName_HatranScript, static_cast<int>(::QLocale::HatranScript), 161},
    {sipName_Hausa, static_cast<int>(::QLocale::Hausa), 156},
    {sipName_Hawaiian, static_cast<int>(::QLocale::Hawaiian), 156},
    {sipName_HeardAndMcDonaldIslands, static_cast<int>(::QLocale::HeardAndMcDonaldIslands), 150},
    {sipName_Hebrew, static_cast<int>(::QLocale::Hebrew), 156},
    {sipName_HebrewScript, static_cast<int>(::QLocale::HebrewScript), 161},
    {sipName_Herero, static_cast<int>(::QLocale::Herero), 156},
    {sipName_HieroglyphicLuwian, static_cast<int>(::QLocale::HieroglyphicLuwian), 156},
    {sipName_Hindi, static_cast<int>(::QLocale::Hindi), 156},
    {sipName_HiraganaScript, static_cast<int>(::QLocale::HiraganaScript), 161},
    {sipName_HiriMotu, static_cast<int>(::QLocale::HiriMotu), 156},
    {sipName_HmongNjua, static_cast<int>(::QLocale::HmongNjua), 156},
    {sipName_Ho, static_cast<int>(::QLocale::Ho), 156},
    {sipName_Honduras, static_cast<int>(::QLocale::Honduras), 150},
    {sipName_HongKong, static_cast<int>(::QLocale::HongKong), 150},
    {sipName_Hungarian, static_cast<int>(::QLocale::Hungarian), 156},
    {sipName_Hungary, static_cast<int>(::QLocale::Hungary), 150},
    {sipName_Iceland, static_cast<int>(::QLocale::Iceland), 150},
    {sipName_Icelandic, static_cast<int>(::QLocale::Icelandic), 156},
    {sipName_Ido, static_cast<int>(::QLocale::Ido), 156},
    {sipName_Igbo, static_cast<int>(::QLocale::Igbo), 156},
    {sipName_ImperialAramaicScript, static_cast<int>(::QLocale::ImperialAramaicScript), 161},
    {sipName_ImperialSystem, static_cast<int>(::QLocale::ImperialSystem), 157},
    {sipName_ImperialUKSystem, static_cast<int>(::QLocale::ImperialUKSystem), 157},
    {sipName_ImperialUSSystem, static_cast<int>(::QLocale::ImperialUSSystem), 157},
    {sipName_InariSami, static_cast<int>(::QLocale::InariSami), 156},
    {sipName_IncludeTrailingZeroesAfterDot, static_cast<int>(::QLocale::IncludeTrailingZeroesAfterDot), 158},
    {sipName_India, static_cast<int>(::QLocale::India), 150},
    {sipName_Indonesia, static_cast<int>(::QLocale::Indonesia), 150},
    {sipName_Indonesian, static_cast<int>(::QLocale::Indonesian), 156},
    {sipName_Ingush, static_cast<int>(::QLocale::Ingush), 156},
    {sipName_InscriptionalPahlaviScript, static_cast<int>(::QLocale::InscriptionalPahlaviScript), 161},
    {sipName_InscriptionalParthianScript, static_cast<int>(::QLocale::InscriptionalParthianScript), 161},
    {sipName_Interlingua, static_cast<int>(::QLocale::Interlingua), 156},
    {sipName_Interlingue, static_cast<int>(::QLocale::Interlingue), 156},
    {sipName_Inuktitut, static_cast<int>(::QLocale::Inuktitut), 156},
    {sipName_Inupiak, static_cast<int>(::QLocale::Inupiak), 156},
    {sipName_Iran, static_cast<int>(::QLocale::Iran), 150},
    {sipName_Iraq, static_cast<int>(::QLocale::Iraq), 150},
    {sipName_Ireland, static_cast<int>(::QLocale::Ireland), 150},
    {sipName_Irish, static_cast<int>(::QLocale::Irish), 156},
    {sipName_IsleOfMan, static_cast<int>(::QLocale::IsleOfMan), 150},
    {sipName_Israel, static_cast<int>(::QLocale::Israel), 150},
    {sipName_Italian, static_cast<int>(::QLocale::Italian), 156},
    {sipName_Italy, static_cast<int>(::QLocale::Italy), 150},
    {sipName_IvoryCoast, static_cast<int>(::QLocale::IvoryCoast), 150},
    {sipName_Jamaica, static_cast<int>(::QLocale::Jamaica), 150},
    {sipName_JamoScript, static_cast<int>(::QLocale::JamoScript), 161},
    {sipName_Japan, static_cast<int>(::QLocale::Japan), 150},
    {sipName_Japanese, static_cast<int>(::QLocale::Japanese), 156},
    {sipName_JapaneseScript, static_cast<int>(::QLocale::JapaneseScript), 161},
    {sipName_Javanese, static_cast<int>(::QLocale::Javanese), 156},
    {sipName_JavaneseScript, static_cast<int>(::QLocale::JavaneseScript), 161},
    {sipName_Jersey, static_cast<int>(::QLocale::Jersey), 150},
    {sipName_Jju, static_cast<int>(::QLocale::Jju), 156},
    {sipName_JolaFonyi, static_cast<int>(::QLocale::JolaFonyi), 156},
    {sipName_Jordan, static_cast<int>(::QLocale::Jordan), 150},
    {sipName_Kabuverdianu, static_cast<int>(::QLocale::Kabuverdianu), 156},
    {sipName_Kabyle, static_cast<int>(::QLocale::Kabyle), 156},
    {sipName_KaithiScript, static_cast<int>(::QLocale::KaithiScript), 161},
    {sipName_Kako, static_cast<int>(::QLocale::Kako), 156},
    {sipName_Kalenjin, static_cast<int>(::QLocale::Kalenjin), 156},
    {sipName_Kamba, static_cast<int>(::QLocale::Kamba), 156},
    {sipName_Kannada, static_cast<int>(::QLocale::Kannada), 156},
    {sipName_KannadaScript, static_cast<int>(::QLocale::KannadaScript), 161},
    {sipName_Kanuri, static_cast<int>(::QLocale::Kanuri), 156},
    {sipName_Kashmiri, static_cast<int>(::QLocale::Kashmiri), 156},
    {sipName_KatakanaScript, static_cast<int>(::QLocale::KatakanaScript), 161},
    {sipName_KayahLiScript, static_cast<int>(::QLocale::KayahLiScript), 161},
    {sipName_Kazakh, static_cast<int>(::QLocale::Kazakh), 156},
    {sipName_Kazakhstan, static_cast<int>(::QLocale::Kazakhstan), 150},
    {sipName_Kenya, static_cast<int>(::QLocale::Kenya), 150},
    {sipName_Kenyang, static_cast<int>(::QLocale::Kenyang), 156},
    {sipName_KharoshthiScript, static_cast<int>(::QLocale::KharoshthiScript), 161},
    {sipName_Khmer, static_cast<int>(::QLocale::Khmer), 156},
    {sipName_KhmerScript, static_cast<int>(::QLocale::KhmerScript), 161},
    {sipName_KhojkiScript, static_cast<int>(::QLocale::KhojkiScript), 161},
    {sipName_KhudawadiScript, static_cast<int>(::QLocale::KhudawadiScript), 161},
    {sipName_Kiche, static_cast<int>(::QLocale::Kiche), 156},
    {sipName_Kikuyu, static_cast<int>(::QLocale::Kikuyu), 156},
    {sipName_Kinyarwanda, static_cast<int>(::QLocale::Kinyarwanda), 156},
    {sipName_Kirghiz, static_cast<int>(::QLocale::Kirghiz), 156},
    {sipName_Kiribati, static_cast<int>(::QLocale::Kiribati), 150},
    {sipName_Komi, static_cast<int>(::QLocale::Komi), 156},
    {sipName_Kongo, static_cast<int>(::QLocale::Kongo), 156},
    {sipName_Konkani, static_cast<int>(::QLocale::Konkani), 156},
    {sipName_Korean, static_cast<int>(::QLocale::Korean), 156},
    {sipName_KoreanScript, static_cast<int>(::QLocale::KoreanScript), 161},
    {sipName_Koro, static_cast<int>(::QLocale::Koro), 156},
    {sipName_Kosovo, static_cast<int>(::QLocale::Kosovo), 150},
    {sipName_KoyraChiini, static_cast<int>(::QLocale::KoyraChiini), 156},
    {sipName_KoyraboroSenni, static_cast<int>(::QLocale::KoyraboroSenni), 156},
    {sipName_Kpelle, static_cast<int>(::QLocale::Kpelle), 156},
    {sipName_Kurdish, static_cast<int>(::QLocale::Kurdish), 156},
    {sipName_Kurundi, static_cast<int>(::QLocale::Kurundi), 156},
    {sipName_Kuwait, static_cast<int>(::QLocale::Kuwait), 150},
    {sipName_Kwanyama, static_cast<int>(::QLocale::Kwanyama), 156},
    {sipName_Kwasio, static_cast<int>(::QLocale::Kwasio), 156},
    {sipName_Kyrgyzstan, static_cast<int>(::QLocale::Kyrgyzstan), 150},
    {sipName_Lakota, static_cast<int>(::QLocale::Lakota), 156},
    {sipName_Langi, static_cast<int>(::QLocale::Langi), 156},
    {sipName_LannaScript, static_cast<int>(::QLocale::LannaScript), 161},
    {sipName_Lao, static_cast<int>(::QLocale::Lao), 156},
    {sipName_LaoScript, static_cast<int>(::QLocale::LaoScript), 161},
    {sipName_Laos, static_cast<int>(::QLocale::Laos), 150},
    {sipName_LargeFloweryMiao, static_cast<int>(::QLocale::LargeFloweryMiao), 156},
    {sipName_LastCountry, static_cast<int>(::QLocale::LastCountry), 150},
    {sipName_LastLanguage, static_cast<int>(::QLocale::LastLanguage), 156},
    {sipName_Latin, static_cast<int>(::QLocale::Latin), 156},
    {sipName_LatinAmerica, static_cast<int>(::QLocale::LatinAmerica), 150},
    {sipName_LatinAmericaAndTheCaribbean, static_cast<int>(::QLocale::LatinAmericaAndTheCaribbean), 150},
    {sipName_LatinScript, static_cast<int>(::QLocale::LatinScript), 161},
    {sipName_Latvia, static_cast<int>(::QLocale::Latvia), 150},
    {sipName_Latvian, static_cast<int>(::QLocale::Latvian), 156},
    {sipName_Lebanon, static_cast<int>(::QLocale::Lebanon), 150},
    {sipName_Lepcha, static_cast<int>(::QLocale::Lepcha), 156},
    {sipName_LepchaScript, static_cast<int>(::QLocale::LepchaScript), 161},
    {sipName_Lesotho, static_cast<int>(::QLocale::Lesotho), 150},
    {sipName_Lezghian, static_cast<int>(::QLocale::Lezghian), 156},
    {sipName_Liberia, static_cast<int>(::QLocale::Liberia), 150},
    {sipName_Libya, static_cast<int>(::QLocale::Libya), 150},
    {sipName_Liechtenstein, static_cast<int>(::QLocale::Liechtenstein), 150},
    {sipName_Limbu, static_cast<int>(::QLocale::Limbu), 156},
    {sipName_LimbuScript, static_cast<int>(::QLocale::LimbuScript), 161},
    {sipName_Limburgish, static_cast<int>(::QLocale::Limburgish), 156},
    {sipName_LinearA, static_cast<int>(::QLocale::LinearA), 156},
    {sipName_LinearAScript, static_cast<int>(::QLocale::LinearAScript), 161},
    {sipName_LinearBScript, static_cast<int>(::QLocale::LinearBScript), 161},
    {sipName_Lingala, static_cast<int>(::QLocale::Lingala), 156},
    {sipName_Lisu, static_cast<int>(::QLocale::Lisu), 156},
    {sipName_LiteraryChinese, static_cast<int>(::QLocale::LiteraryChinese), 156},
    {sipName_Lithuania, static_cast<int>(::QLocale::Lithuania), 150},
    {sipName_Lithuanian, static_cast<int>(::QLocale::Lithuanian), 156},
    {sipName_Lojban, static_cast<int>(::QLocale::Lojban), 156},
    {sipName_LongFormat, static_cast<int>(::QLocale::LongFormat), 155},
    {sipName_LowGerman, static_cast<int>(::QLocale::LowGerman), 156},
    {sipName_LowerSorbian, static_cast<int>(::QLocale::LowerSorbian), 156},
    {sipName_Lu, static_cast<int>(::QLocale::Lu), 156},
    {sipName_LubaKatanga, static_cast<int>(::QLocale::LubaKatanga), 156},
    {sipName_LuleSami, static_cast<int>(::QLocale::LuleSami), 156},
    {sipName_Luo, static_cast<int>(::QLocale::Luo), 156},
    {sipName_Luxembourg, static_cast<int>(::QLocale::Luxembourg), 150},
    {sipName_Luxembourgish, static_cast<int>(::QLocale::Luxembourgish), 156},
    {sipName_Luyia, static_cast<int>(::QLocale::Luyia), 156},
    {sipName_Lycian, static_cast<int>(::QLocale::Lycian), 156},
    {sipName_LycianScript, static_cast<int>(::QLocale::LycianScript), 161},
    {sipName_Lydian, static_cast<int>(::QLocale::Lydian), 156},
    {sipName_LydianScript, static_cast<int>(::QLocale::LydianScript), 161},
    {sipName_Macau, static_cast<int>(::QLocale::Macau), 150},
    {sipName_Macedonia, static_cast<int>(::QLocale::Macedonia), 150},
    {sipName_Macedonian, static_cast<int>(::QLocale::Macedonian), 156},
    {sipName_Machame, static_cast<int>(::QLocale::Machame), 156},
    {sipName_Madagascar, static_cast<int>(::QLocale::Madagascar), 150},
    {sipName_MahajaniScript, static_cast<int>(::QLocale::MahajaniScript), 161},
    {sipName_Maithili, static_cast<int>(::QLocale::Maithili), 156},
    {sipName_MakhuwaMeetto, static_cast<int>(::QLocale::MakhuwaMeetto), 156},
    {sipName_Makonde, static_cast<int>(::QLocale::Makonde), 156},
    {sipName_Malagasy, static_cast<int>(::QLocale::Malagasy), 156},
    {sipName_Malawi, static_cast<int>(::QLocale::Malawi), 150},
    {sipName_Malay, static_cast<int>(::QLocale::Malay), 156},
    {sipName_Malayalam, static_cast<int>(::QLocale::Malayalam), 156},
    {sipName_MalayalamScript, static_cast<int>(::QLocale::MalayalamScript), 161},
    {sipName_Malaysia, static_cast<int>(::QLocale::Malaysia), 150},
    {sipName_Maldives, static_cast<int>(::QLocale::Maldives), 150},
    {sipName_Mali, static_cast<int>(::QLocale::Mali), 150},
    {sipName_Malta, static_cast<int>(::QLocale::Malta), 150},
    {sipName_Maltese, static_cast<int>(::QLocale::Maltese), 156},
    {sipName_MandaeanScript, static_cast<int>(::QLocale::MandaeanScript), 161},
    {sipName_Mandingo, static_cast<int>(::QLocale::Mandingo), 156},
    {sipName_ManichaeanMiddlePersian, static_cast<int>(::QLocale::ManichaeanMiddlePersian), 156},
    {sipName_ManichaeanScript, static_cast<int>(::QLocale::ManichaeanScript), 161},
    {sipName_Manipuri, static_cast<int>(::QLocale::Manipuri), 156},
    {sipName_Manx, static_cast<int>(::QLocale::Manx), 156},
    {sipName_Maori, static_cast<int>(::QLocale::Maori), 156},
    {sipName_Mapuche, static_cast<int>(::QLocale::Mapuche), 156},
    {sipName_Marathi, static_cast<int>(::QLocale::Marathi), 156},
    {sipName_MarchenScript, static_cast<int>(::QLocale::MarchenScript), 161},
    {sipName_MarshallIslands, static_cast<int>(::QLocale::MarshallIslands), 150},
    {sipName_Marshallese, static_cast<int>(::QLocale::Marshallese), 156},
    {sipName_Martinique, static_cast<int>(::QLocale::Martinique), 150},
    {sipName_Masai, static_cast<int>(::QLocale::Masai), 156},
    {sipName_Mauritania, static_cast<int>(::QLocale::Mauritania), 150},
    {sipName_Mauritius, static_cast<int>(::QLocale::Mauritius), 150},
    {sipName_Mayotte, static_cast<int>(::QLocale::Mayotte), 150},
    {sipName_Mazanderani, static_cast<int>(::QLocale::Mazanderani), 156},
    {sipName_MeiteiMayekScript, static_cast<int>(::QLocale::MeiteiMayekScript), 161},
    {sipName_Mende, static_cast<int>(::QLocale::Mende), 156},
    {sipName_MendeKikakuiScript, static_cast<int>(::QLocale::MendeKikakuiScript), 161},
    {sipName_Meroitic, static_cast<int>(::QLocale::Meroitic), 156},
    {sipName_MeroiticCursiveScript, static_cast<int>(::QLocale::MeroiticCursiveScript), 161},
    {sipName_MeroiticScript, static_cast<int>(::QLocale::MeroiticScript), 161},
    {sipName_Meru, static_cast<int>(::QLocale::Meru), 156},
    {sipName_Meta, static_cast<int>(::QLocale::Meta), 156},
    {sipName_MetricSystem, static_cast<int>(::QLocale::MetricSystem), 157},
    {sipName_Mexico, static_cast<int>(::QLocale::Mexico), 150},
    {sipName_Micronesia, static_cast<int>(::QLocale::Micronesia), 150},
    {sipName_ModiScript, static_cast<int>(::QLocale::ModiScript), 161},
    {sipName_Mohawk, static_cast<int>(::QLocale::Mohawk), 156},
    {sipName_Moldavian, static_cast<int>(::QLocale::Moldavian), 156},
    {sipName_Moldova, static_cast<int>(::QLocale::Moldova), 150},
    {sipName_Monaco, static_cast<int>(::QLocale::Monaco), 150},
    {sipName_Mongolia, static_cast<int>(::QLocale::Mongolia), 150},
    {sipName_Mongolian, static_cast<int>(::QLocale::Mongolian), 156},
    {sipName_MongolianScript, static_cast<int>(::QLocale::MongolianScript), 161},
    {sipName_Mono, static_cast<int>(::QLocale::Mono), 156},
    {sipName_Montenegro, static_cast<int>(::QLocale::Montenegro), 150},
    {sipName_Montserrat, static_cast<int>(::QLocale::Montserrat), 150},
    {sipName_Morisyen, static_cast<int>(::QLocale::Morisyen), 156},
    {sipName_Morocco, static_cast<int>(::QLocale::Morocco), 150},
    {sipName_Mozambique, static_cast<int>(::QLocale::Mozambique), 150},
    {sipName_MroScript, static_cast<int>(::QLocale::MroScript), 161},
    {sipName_Mru, static_cast<int>(::QLocale::Mru), 156},
    {sipName_MultaniScript, static_cast<int>(::QLocale::MultaniScript), 161},
    {sipName_Mundang, static_cast<int>(::QLocale::Mundang), 156},
    {sipName_Muscogee, static_cast<int>(::QLocale::Muscogee), 156},
    {sipName_Myanmar, static_cast<int>(::QLocale::Myanmar), 150},
    {sipName_MyanmarScript, static_cast<int>(::QLocale::MyanmarScript), 161},
    {sipName_NabataeanScript, static_cast<int>(::QLocale::NabataeanScript), 161},
    {sipName_Nama, static_cast<int>(::QLocale::Nama), 156},
    {sipName_Namibia, static_cast<int>(::QLocale::Namibia), 150},
    {sipName_NarrowFormat, static_cast<int>(::QLocale::NarrowFormat), 155},
    {sipName_NauruCountry, static_cast<int>(::QLocale::NauruCountry), 150},
    {sipName_NauruLanguage, static_cast<int>(::QLocale::NauruLanguage), 156},
    {sipName_Navaho, static_cast<int>(::QLocale::Navaho), 156},
    {sipName_Ndonga, static_cast<int>(::QLocale::Ndonga), 156},
    {sipName_Nepal, static_cast<int>(::QLocale::Nepal), 150},
    {sipName_Nepali, static_cast<int>(::QLocale::Nepali), 156},
    {sipName_Netherlands, static_cast<int>(::QLocale::Netherlands), 150},
    {sipName_NewCaledonia, static_cast<int>(::QLocale::NewCaledonia), 150},
    {sipName_NewTaiLueScript, static_cast<int>(::QLocale::NewTaiLueScript), 161},
    {sipName_NewZealand, static_cast<int>(::QLocale::NewZealand), 150},
    {sipName_NewaScript, static_cast<int>(::QLocale::NewaScript), 161},
    {sipName_Newari, static_cast<int>(::QLocale::Newari), 156},
    {sipName_Ngiemboon, static_cast<int>(::QLocale::Ngiemboon), 156},
    {sipName_Ngomba, static_cast<int>(::QLocale::Ngomba), 156},
    {sipName_Nicaragua, static_cast<int>(::QLocale::Nicaragua), 150},
    {sipName_Niger, static_cast<int>(::QLocale::Niger), 150},
    {sipName_Nigeria, static_cast<int>(::QLocale::Nigeria), 150},
    {sipName_NigerianPidgin, static_cast<int>(::QLocale::NigerianPidgin), 156},
    {sipName_Niue, static_cast<int>(::QLocale::Niue), 150},
    {sipName_Nko, static_cast<int>(::QLocale::Nko), 156},
    {sipName_NkoScript, static_cast<int>(::QLocale::NkoScript), 161},
    {sipName_NorfolkIsland, static_cast<int>(::QLocale::NorfolkIsland), 150},
    {sipName_NorthKorea, static_cast<int>(::QLocale::NorthKorea), 150},
    {sipName_NorthNdebele, static_cast<int>(::QLocale::NorthNdebele), 156},
    {sipName_NorthernLuri, static_cast<int>(::QLocale::NorthernLuri), 156},
    {sipName_NorthernMarianaIslands, static_cast<int>(::QLocale::NorthernMarianaIslands), 150},
    {sipName_NorthernSami, static_cast<int>(::QLocale::NorthernSami), 156},
    {sipName_NorthernSotho, static_cast<int>(::QLocale::NorthernSotho), 156},
    {sipName_NorthernThai, static_cast<int>(::QLocale::NorthernThai), 156},
    {sipName_Norway, static_cast<int>(::QLocale::Norway), 150},
    {sipName_Norwegian, static_cast<int>(::QLocale::Norwegian), 156},
    {sipName_NorwegianBokmal, static_cast<int>(::QLocale::NorwegianBokmal), 156},
    {sipName_NorwegianNynorsk, static_cast<int>(::QLocale::NorwegianNynorsk), 156},
    {sipName_Nuer, static_cast<int>(::QLocale::Nuer), 156},
    {sipName_Nyanja, static_cast<int>(::QLocale::Nyanja), 156},
    {sipName_Nyankole, static_cast<int>(::QLocale::Nyankole), 156},
    {sipName_Occitan, static_cast<int>(::QLocale::Occitan), 156},
    {sipName_OghamScript, static_cast<int>(::QLocale::OghamScript), 161},
    {sipName_Ojibwa, static_cast<int>(::QLocale::Ojibwa), 156},
    {sipName_OlChikiScript, static_cast<int>(::QLocale::OlChikiScript), 161},
    {sipName_OldHungarianScript, static_cast<int>(::QLocale::OldHungarianScript), 161},
    {sipName_OldIrish, static_cast<int>(::QLocale::OldIrish), 156},
    {sipName_OldItalicScript, static_cast<int>(::QLocale::OldItalicScript), 161},
    {sipName_OldNorse, static_cast<int>(::QLocale::OldNorse), 156},
    {sipName_OldNorthArabianScript, static_cast<int>(::QLocale::OldNorthArabianScript), 161},
    {sipName_OldPermicScript, static_cast<int>(::QLocale::OldPermicScript), 161},
    {sipName_OldPersian, static_cast<int>(::QLocale::OldPersian), 156},
    {sipName_OldPersianScript, static_cast<int>(::QLocale::OldPersianScript), 161},
    {sipName_OldSouthArabianScript, static_cast<int>(::QLocale::OldSouthArabianScript), 161},
    {sipName_OldTurkish, static_cast<int>(::QLocale::OldTurkish), 156},
    {sipName_Oman, static_cast<int>(::QLocale::Oman), 150},
    {sipName_OmitGroupSeparator, static_cast<int>(::QLocale::OmitGroupSeparator), 158},
    {sipName_OmitLeadingZeroInExponent, static_cast<int>(::QLocale::OmitLeadingZeroInExponent), 158},
    {sipName_Oriya, static_cast<int>(::QLocale::Oriya), 156},
    {sipName_OriyaScript, static_cast<int>(::QLocale::OriyaScript), 161},
    {sipName_OrkhonScript, static_cast<int>(::QLocale::OrkhonScript), 161},
    {sipName_Oromo, static_cast<int>(::QLocale::Oromo), 156},
    {sipName_Osage, static_cast<int>(::QLocale::Osage), 156},
    {sipName_OsageScript, static_cast<int>(::QLocale::OsageScript), 161},
    {sipName_OsmanyaScript, static_cast<int>(::QLocale::OsmanyaScript), 161},
    {sipName_Ossetic, static_cast<int>(::QLocale::Ossetic), 156},
    {sipName_OutlyingOceania, static_cast<int>(::QLocale::OutlyingOceania), 150},
    {sipName_PahawhHmongScript, static_cast<int>(::QLocale::PahawhHmongScript), 161},
    {sipName_Pahlavi, static_cast<int>(::QLocale::Pahlavi), 156},
    {sipName_Pakistan, static_cast<int>(::QLocale::Pakistan), 150},
    {sipName_Palau, static_cast<int>(::QLocale::Palau), 150},
    {sipName_Palauan, static_cast<int>(::QLocale::Palauan), 156},
    {sipName_PalestinianTerritories, static_cast<int>(::QLocale::PalestinianTerritories), 150},
    {sipName_Pali, static_cast<int>(::QLocale::Pali), 156},
    {sipName_PalmyreneScript, static_cast<int>(::QLocale::PalmyreneScript), 161},
    {sipName_Panama, static_cast<int>(::QLocale::Panama), 150},
    {sipName_Papiamento, static_cast<int>(::QLocale::Papiamento), 156},
    {sipName_PapuaNewGuinea, static_cast<int>(::QLocale::PapuaNewGuinea), 150},
    {sipName_Paraguay, static_cast<int>(::QLocale::Paraguay), 150},
    {sipName_Parthian, static_cast<int>(::QLocale::Parthian), 156},
    {sipName_Pashto, static_cast<int>(::QLocale::Pashto), 156},
    {sipName_PauCinHauScript, static_cast<int>(::QLocale::PauCinHauScript), 161},
    {sipName_PeoplesRepublicOfCongo, static_cast<int>(::QLocale::PeoplesRepublicOfCongo), 150},
    {sipName_Persian, static_cast<int>(::QLocale::Persian), 156},
    {sipName_Peru, static_cast<int>(::QLocale::Peru), 150},
    {sipName_PhagsPaScript, static_cast<int>(::QLocale::PhagsPaScript), 161},
    {sipName_Philippines, static_cast<int>(::QLocale::Philippines), 150},
    {sipName_Phoenician, static_cast<int>(::QLocale::Phoenician), 156},
    {sipName_PhoenicianScript, static_cast<int>(::QLocale::PhoenicianScript), 161},
    {sipName_Pitcairn, static_cast<int>(::QLocale::Pitcairn), 150},
    {sipName_Poland, static_cast<int>(::QLocale::Poland), 150},
    {sipName_Polish, static_cast<int>(::QLocale::Polish), 156},
    {sipName_PollardPhoneticScript, static_cast<int>(::QLocale::PollardPhoneticScript), 161},
    {sipName_Portugal, static_cast<int>(::QLocale::Portugal), 150},
    {sipName_Portuguese, static_cast<int>(::QLocale::Portuguese), 156},
    {sipName_PrakritLanguage, static_cast<int>(::QLocale::PrakritLanguage), 156},
    {sipName_Prussian, static_cast<int>(::QLocale::Prussian), 156},
    {sipName_PsalterPahlaviScript, static_cast<int>(::QLocale::PsalterPahlaviScript), 161},
    {sipName_PuertoRico, static_cast<int>(::QLocale::PuertoRico), 150},
    {sipName_Punjabi, static_cast<int>(::QLocale::Punjabi), 156},
    {sipName_Qatar, static_cast<int>(::QLocale::Qatar), 150},
    {sipName_Quechua, static_cast<int>(::QLocale::Quechua), 156},
    {sipName_Rejang, static_cast<int>(::QLocale::Rejang), 156},
    {sipName_RejangScript, static_cast<int>(::QLocale::RejangScript), 161},
    {sipName_RejectGroupSeparator, static_cast<int>(::QLocale::RejectGroupSeparator), 158},
    {sipName_RejectLeadingZeroInExponent, static_cast<int>(::QLocale::RejectLeadingZeroInExponent), 158},
    {sipName_RejectTrailingZeroesAfterDot, static_cast<int>(::QLocale::RejectTrailingZeroesAfterDot), 158},
    {sipName_RepublicOfKorea, static_cast<int>(::QLocale::RepublicOfKorea), 150},
    {sipName_Reunion, static_cast<int>(::QLocale::Reunion), 150},
    {sipName_RhaetoRomance, static_cast<int>(::QLocale::RhaetoRomance), 156},
    {sipName_Romania, static_cast<int>(::QLocale::Romania), 150},
    {sipName_Romanian, static_cast<int>(::QLocale::Romanian), 156},
    {sipName_Romansh, static_cast<int>(::QLocale::Romansh), 156},
    {sipName_Rombo, static_cast<int>(::QLocale::Rombo), 156},
    {sipName_Rundi, static_cast<int>(::QLocale::Rundi), 156},
    {sipName_RunicScript, static_cast<int>(::QLocale::RunicScript), 161},
    {sipName_Russia, static_cast<int>(::QLocale::Russia), 150},
    {sipName_Russian, static_cast<int>(::QLocale::Russian), 156},
    {sipName_RussianFederation, static_cast<int>(::QLocale::RussianFederation), 150},
    {sipName_Rwa, static_cast<int>(::QLocale::Rwa), 156},
    {sipName_Rwanda, static_cast<int>(::QLocale::Rwanda), 150},
    {sipName_Sabaean, static_cast<int>(::QLocale::Sabaean), 156},
    {sipName_Saho, static_cast<int>(::QLocale::Saho), 156},
    {sipName_SaintBarthelemy, static_cast<int>(::QLocale::SaintBarthelemy), 150},
    {sipName_SaintHelena, static_cast<int>(::QLocale::SaintHelena), 150},
    {sipName_SaintKittsAndNevis, static_cast<int>(::QLocale::SaintKittsAndNevis), 150},
    {sipName_SaintLucia, static_cast<int>(::QLocale::SaintLucia), 150},
    {sipName_SaintMartin, static_cast<int>(::QLocale::SaintMartin), 150},
    {sipName_SaintPierreAndMiquelon, static_cast<int>(::QLocale::SaintPierreAndMiquelon), 150},
    {sipName_SaintVincentAndTheGrenadines, static_cast<int>(::QLocale::SaintVincentAndTheGrenadines), 150},
    {sipName_Sakha, static_cast<int>(::QLocale::Sakha), 156},
    {sipName_Samaritan, static_cast<int>(::QLocale::Samaritan), 156},
    {sipName_SamaritanScript, static_cast<int>(::QLocale::SamaritanScript), 161},
    {sipName_Samburu, static_cast<int>(::QLocale::Samburu), 156},
    {sipName_Samoa, static_cast<int>(::QLocale::Samoa), 150},
    {sipName_Samoan, static_cast<int>(::QLocale::Samoan), 156},
    {sipName_SanMarino, static_cast<int>(::QLocale::SanMarino), 150},
    {sipName_Sango, static_cast<int>(::QLocale::Sango), 156},
    {sipName_Sangu, static_cast<int>(::QLocale::Sangu), 156},
    {sipName_Sanskrit, static_cast<int>(::QLocale::Sanskrit), 156},
    {sipName_Santali, static_cast<int>(::QLocale::Santali), 156},
    {sipName_SaoTomeAndPrincipe, static_cast<int>(::QLocale::SaoTomeAndPrincipe), 150},
    {sipName_Saraiki, static_cast<int>(::QLocale::Saraiki), 156},
    {sipName_Sardinian, static_cast<int>(::QLocale::Sardinian), 156},
    {sipName_SaudiArabia, static_cast<int>(::QLocale::SaudiArabia), 150},
    {sipName_Saurashtra, static_cast<int>(::QLocale::Saurashtra), 156},
    {sipName_SaurashtraScript, static_cast<int>(::QLocale::SaurashtraScript), 161},
    {sipName_Sena, static_cast<int>(::QLocale::Sena), 156},
    {sipName_Senegal, static_cast<int>(::QLocale::Senegal), 150},
    {sipName_Serbia, static_cast<int>(::QLocale::Serbia), 150},
    {sipName_Serbian, static_cast<int>(::QLocale::Serbian), 156},
    {sipName_SerboCroatian, static_cast<int>(::QLocale::SerboCroatian), 156},
    {sipName_Seychelles, static_cast<int>(::QLocale::Seychelles), 150},
    {sipName_Shambala, static_cast<int>(::QLocale::Shambala), 156},
    {sipName_SharadaScript, static_cast<int>(::QLocale::SharadaScript), 161},
    {sipName_ShavianScript, static_cast<int>(::QLocale::ShavianScript), 161},
    {sipName_Shona, static_cast<int>(::QLocale::Shona), 156},
    {sipName_ShortFormat, static_cast<int>(::QLocale::ShortFormat), 155},
    {sipName_SichuanYi, static_cast<int>(::QLocale::SichuanYi), 156},
    {sipName_Sicilian, static_cast<int>(::QLocale::Sicilian), 156},
    {sipName_Sidamo, static_cast<int>(::QLocale::Sidamo), 156},
    {sipName_SiddhamScript, static_cast<int>(::QLocale::SiddhamScript), 161},
    {sipName_SierraLeone, static_cast<int>(::QLocale::SierraLeone), 150},
    {sipName_SignWritingScript, static_cast<int>(::QLocale::SignWritingScript), 161},
    {sipName_Silesian, static_cast<int>(::QLocale::Silesian), 156},
    {sipName_SimplifiedChineseScript, static_cast<int>(::QLocale::SimplifiedChineseScript), 161},
    {sipName_SimplifiedHanScript, static_cast<int>(::QLocale::SimplifiedHanScript), 161},
    {sipName_Sindhi, static_cast<int>(::QLocale::Sindhi), 156},
    {sipName_Singapore, static_cast<int>(::QLocale::Singapore), 150},
    {sipName_Sinhala, static_cast<int>(::QLocale::Sinhala), 156},
    {sipName_SinhalaScript, static_cast<int>(::QLocale::SinhalaScript), 161},
    {sipName_SintMaarten, static_cast<int>(::QLocale::SintMaarten), 150},
    {sipName_SkoltSami, static_cast<int>(::QLocale::SkoltSami), 156},
    {sipName_Slovak, static_cast<int>(::QLocale::Slovak), 156},
    {sipName_Slovakia, static_cast<int>(::QLocale::Slovakia), 150},
    {sipName_Slovenia, static_cast<int>(::QLocale::Slovenia), 150},
    {sipName_Slovenian, static_cast<int>(::QLocale::Slovenian), 156},
    {sipName_Soga, static_cast<int>(::QLocale::Soga), 156},
    {sipName_SolomonIslands, static_cast<int>(::QLocale::SolomonIslands), 150},
    {sipName_Somali, static_cast<int>(::QLocale::Somali), 156},
    {sipName_Somalia, static_cast<int>(::QLocale::Somalia), 150},
    {sipName_Sora, static_cast<int>(::QLocale::Sora), 156},
    {sipName_SoraSompengScript, static_cast<int>(::QLocale::SoraSompengScript), 161},
    {sipName_SouthAfrica, static_cast<int>(::QLocale::SouthAfrica), 150},
    {sipName_SouthGeorgiaAndTheSouthSandwichIslands, static_cast<int>(::QLocale::SouthGeorgiaAndTheSouthSandwichIslands), 150},
    {sipName_SouthKorea, static_cast<int>(::QLocale::SouthKorea), 150},
    {sipName_SouthNdebele, static_cast<int>(::QLocale::SouthNdebele), 156},
    {sipName_SouthSudan, static_cast<int>(::QLocale::SouthSudan), 150},
    {sipName_SouthernKurdish, static_cast<int>(::QLocale::SouthernKurdish), 156},
    {sipName_SouthernSami, static_cast<int>(::QLocale::SouthernSami), 156},
    {sipName_SouthernSotho, static_cast<int>(::QLocale::SouthernSotho), 156},
    {sipName_Spain, static_cast<int>(::QLocale::Spain), 150},
    {sipName_Spanish, static_cast<int>(::QLocale::Spanish), 156},
    {sipName_SriLanka, static_cast<int>(::QLocale::SriLanka), 150},
    {sipName_StandardMoroccanTamazight, static_cast<int>(::QLocale::StandardMoroccanTamazight), 156},
    {sipName_StandardQuotation, static_cast<int>(::QLocale::StandardQuotation), 160},
    {sipName_Sudan, static_cast<int>(::QLocale::Sudan), 150},
    {sipName_Sundanese, static_cast<int>(::QLocale::Sundanese), 156},
    {sipName_SundaneseScript, static_cast<int>(::QLocale::SundaneseScript), 161},
    {sipName_Suriname, static_cast<int>(::QLocale::Suriname), 150},
    {sipName_SvalbardAndJanMayenIslands, static_cast<int>(::QLocale::SvalbardAndJanMayenIslands), 150},
    {sipName_Swahili, static_cast<int>(::QLocale::Swahili), 156},
    {sipName_Swati, static_cast<int>(::QLocale::Swati), 156},
    {sipName_Swaziland, static_cast<int>(::QLocale::Swaziland), 150},
    {sipName_Sweden, static_cast<int>(::QLocale::Sweden), 150},
    {sipName_Swedish, static_cast<int>(::QLocale::Swedish), 156},
    {sipName_SwissGerman, static_cast<int>(::QLocale::SwissGerman), 156},
    {sipName_Switzerland, static_cast<int>(::QLocale::Switzerland), 150},
    {sipName_Sylheti, static_cast<int>(::QLocale::Sylheti), 156},
    {sipName_SylotiNagriScript, static_cast<int>(::QLocale::SylotiNagriScript), 161},
    {sipName_Syria, static_cast<int>(::QLocale::Syria), 150},
    {sipName_Syriac, static_cast<int>(::QLocale::Syriac), 156},
    {sipName_SyriacScript, static_cast<int>(::QLocale::SyriacScript), 161},
    {sipName_SyrianArabRepublic, static_cast<int>(::QLocale::SyrianArabRepublic), 150},
    {sipName_Tachelhit, static_cast<int>(::QLocale::Tachelhit), 156},
    {sipName_Tagalog, static_cast<int>(::QLocale::Tagalog), 156},
    {sipName_TagalogScript, static_cast<int>(::QLocale::TagalogScript), 161},
    {sipName_Tagbanwa, static_cast<int>(::QLocale::Tagbanwa), 156},
    {sipName_TagbanwaScript, static_cast<int>(::QLocale::TagbanwaScript), 161},
    {sipName_Tahitian, static_cast<int>(::QLocale::Tahitian), 156},
    {sipName_TaiDam, static_cast<int>(::QLocale::TaiDam), 156},
    {sipName_TaiLeScript, static_cast<int>(::QLocale::TaiLeScript), 161},
    {sipName_TaiNua, static_cast<int>(::QLocale::TaiNua), 156},
    {sipName_TaiVietScript, static_cast<int>(::QLocale::TaiVietScript), 161},
    {sipName_Taita, static_cast<int>(::QLocale::Taita), 156},
    {sipName_Taiwan, static_cast<int>(::QLocale::Taiwan), 150},
    {sipName_Tajik, static_cast<int>(::QLocale::Tajik), 156},
    {sipName_Tajikistan, static_cast<int>(::QLocale::Tajikistan), 150},
    {sipName_TakriScript, static_cast<int>(::QLocale::TakriScript), 161},
    {sipName_Tamil, static_cast<int>(::QLocale::Tamil), 156},
    {sipName_TamilScript, static_cast<int>(::QLocale::TamilScript), 161},
    {sipName_Tangut, static_cast<int>(::QLocale::Tangut), 156},
    {sipName_TangutScript, static_cast<int>(::QLocale::TangutScript), 161},
    {sipName_Tanzania, static_cast<int>(::QLocale::Tanzania), 150},
    {sipName_Taroko, static_cast<int>(::QLocale::Taroko), 156},
    {sipName_Tasawaq, static_cast<int>(::QLocale::Tasawaq), 156},
    {sipName_Tatar, static_cast<int>(::QLocale::Tatar), 156},
    {sipName_TedimChin, static_cast<int>(::QLocale::TedimChin), 156},
    {sipName_Telugu, static_cast<int>(::QLocale::Telugu), 156},
    {sipName_TeluguScript, static_cast<int>(::QLocale::TeluguScript), 161},
    {sipName_Teso, static_cast<int>(::QLocale::Teso), 156},
    {sipName_ThaanaScript, static_cast<int>(::QLocale::ThaanaScript), 161},
    {sipName_Thai, static_cast<int>(::QLocale::Thai), 156},
    {sipName_ThaiScript, static_cast<int>(::QLocale::ThaiScript), 161},
    {sipName_Thailand, static_cast<int>(::QLocale::Thailand), 150},
    {sipName_Tibetan, static_cast<int>(::QLocale::Tibetan), 156},
    {sipName_TibetanScript, static_cast<int>(::QLocale::TibetanScript), 161},
    {sipName_TifinaghScript, static_cast<int>(::QLocale::TifinaghScript), 161},
    {sipName_Tigre, static_cast<int>(::QLocale::Tigre), 156},
    {sipName_Tigrinya, static_cast<int>(::QLocale::Tigrinya), 156},
    {sipName_TirhutaScript, static_cast<int>(::QLocale::TirhutaScript), 161},
    {sipName_Togo, static_cast<int>(::QLocale::Togo), 150},
    {sipName_TokPisin, static_cast<int>(::QLocale::TokPisin), 156},
    {sipName_Tokelau, static_cast<int>(::QLocale::Tokelau), 150},
    {sipName_TokelauCountry, static_cast<int>(::QLocale::TokelauCountry), 150},
    {sipName_TokelauLanguage, static_cast<int>(::QLocale::TokelauLanguage), 156},
    {sipName_Tonga, static_cast<int>(::QLocale::Tonga), 150},
    {sipName_Tongan, static_cast<int>(::QLocale::Tongan), 156},
    {sipName_TraditionalChineseScript, static_cast<int>(::QLocale::TraditionalChineseScript), 161},
    {sipName_TraditionalHanScript, static_cast<int>(::QLocale::TraditionalHanScript), 161},
    {sipName_TrinidadAndTobago, static_cast<int>(::QLocale::TrinidadAndTobago), 150},
    {sipName_TristanDaCunha, static_cast<int>(::QLocale::TristanDaCunha), 150},
    {sipName_Tsonga, static_cast<int>(::QLocale::Tsonga), 156},
    {sipName_Tswana, static_cast<int>(::QLocale::Tswana), 156},
    {sipName_Tunisia, static_cast<int>(::QLocale::Tunisia), 150},
    {sipName_Turkey, static_cast<int>(::QLocale::Turkey), 150},
    {sipName_Turkish, static_cast<int>(::QLocale::Turkish), 156},
    {sipName_Turkmen, static_cast<int>(::QLocale::Turkmen), 156},
    {sipName_Turkmenistan, static_cast<int>(::QLocale::Turkmenistan), 150},
    {sipName_TurksAndCaicosIslands, static_cast<int>(::QLocale::TurksAndCaicosIslands), 150},
    {sipName_Tuvalu, static_cast<int>(::QLocale::Tuvalu), 150},
    {sipName_TuvaluCountry, static_cast<int>(::QLocale::TuvaluCountry), 150},
    {sipName_TuvaluLanguage, static_cast<int>(::QLocale::TuvaluLanguage), 156},
    {sipName_Twi, static_cast<int>(::QLocale::Twi), 156},
    {sipName_Tyap, static_cast<int>(::QLocale::Tyap), 156},
    {sipName_Uganda, static_cast<int>(::QLocale::Uganda), 150},
    {sipName_Ugaritic, static_cast<int>(::QLocale::Ugaritic), 156},
    {sipName_UgariticScript, static_cast<int>(::QLocale::UgariticScript), 161},
    {sipName_Uighur, static_cast<int>(::QLocale::Uighur), 156},
    {sipName_Uigur, static_cast<int>(::QLocale::Uigur), 156},
    {sipName_Ukraine, static_cast<int>(::QLocale::Ukraine), 150},
    {sipName_Ukrainian, static_cast<int>(::QLocale::Ukrainian), 156},
    {sipName_UncodedLanguages, static_cast<int>(::QLocale::UncodedLanguages), 156},
    {sipName_UnitedArabEmirates, static_cast<int>(::QLocale::UnitedArabEmirates), 150},
    {sipName_UnitedKingdom, static_cast<int>(::QLocale::UnitedKingdom), 150},
    {sipName_UnitedStates, static_cast<int>(::QLocale::UnitedStates), 150},
    {sipName_UnitedStatesMinorOutlyingIslands, static_cast<int>(::QLocale::UnitedStatesMinorOutlyingIslands), 150},
    {sipName_UnitedStatesVirginIslands, static_cast<int>(::QLocale::UnitedStatesVirginIslands), 150},
    {sipName_UpperSorbian, static_cast<int>(::QLocale::UpperSorbian), 156},
    {sipName_Urdu, static_cast<int>(::QLocale::Urdu), 156},
    {sipName_Uruguay, static_cast<int>(::QLocale::Uruguay), 150},
    {sipName_Uzbek, static_cast<int>(::QLocale::Uzbek), 156},
    {sipName_Uzbekistan, static_cast<int>(::QLocale::Uzbekistan), 150},
    {sipName_Vai, static_cast<int>(::QLocale::Vai), 156},
    {sipName_VaiScript, static_cast<int>(::QLocale::VaiScript), 161},
    {sipName_Vanuatu, static_cast<int>(::QLocale::Vanuatu), 150},
    {sipName_VarangKshitiScript, static_cast<int>(::QLocale::VarangKshitiScript), 161},
    {sipName_VaticanCityState, static_cast<int>(::QLocale::VaticanCityState), 150},
    {sipName_Venda, static_cast<int>(::QLocale::Venda), 156},
    {sipName_Venezuela, static_cast<int>(::QLocale::Venezuela), 150},
    {sipName_Vietnam, static_cast<int>(::QLocale::Vietnam), 150},
    {sipName_Vietnamese, static_cast<int>(::QLocale::Vietnamese), 156},
    {sipName_Volapuk, static_cast<int>(::QLocale::Volapuk), 156},
    {sipName_Vunjo, static_cast<int>(::QLocale::Vunjo), 156},
    {sipName_Walamo, static_cast<int>(::QLocale::Walamo), 156},
    {sipName_WallisAndFutunaIslands, static_cast<int>(::QLocale::WallisAndFutunaIslands), 150},
    {sipName_Walloon, static_cast<int>(::QLocale::Walloon), 156},
    {sipName_Walser, static_cast<int>(::QLocale::Walser), 156},
    {sipName_Warlpiri, static_cast<int>(::QLocale::Warlpiri), 156},
    {sipName_Welsh, static_cast<int>(::QLocale::Welsh), 156},
    {sipName_WesternBalochi, static_cast<int>(::QLocale::WesternBalochi), 156},
    {sipName_WesternFrisian, static_cast<int>(::QLocale::WesternFrisian), 156},
    {sipName_WesternSahara, static_cast<int>(::QLocale::WesternSahara), 150},
    {sipName_Wolof, static_cast<int>(::QLocale::Wolof), 156},
    {sipName_World, static_cast<int>(::QLocale::World), 150},
    {sipName_Xhosa, static_cast<int>(::QLocale::Xhosa), 156},
    {sipName_Yangben, static_cast<int>(::QLocale::Yangben), 156},
    {sipName_Yemen, static_cast<int>(::QLocale::Yemen), 150},
    {sipName_YiScript, static_cast<int>(::QLocale::YiScript), 161},
    {sipName_Yiddish, static_cast<int>(::QLocale::Yiddish), 156},
    {sipName_Yoruba, static_cast<int>(::QLocale::Yoruba), 156},
    {sipName_Zambia, static_cast<int>(::QLocale::Zambia), 150},
    {sipName_Zarma, static_cast<int>(::QLocale::Zarma), 156},
    {sipName_Zhuang, static_cast<int>(::QLocale::Zhuang), 156},
    {sipName_Zimbabwe, static_cast<int>(::QLocale::Zimbabwe), 150},
    {sipName_Zulu, static_cast<int>(::QLocale::Zulu), 156},
};

PyDoc_STRVAR(doc_QLocale, "\1QLocale()\n"
"QLocale(name: Optional[str])\n"
"QLocale(language: QLocale.Language, country: QLocale.Country = QLocale.AnyCountry)\n"
"QLocale(other: QLocale)\n"
"QLocale(language: QLocale.Language, script: QLocale.Script, country: QLocale.Country)");


static pyqt5ClassPluginDef plugin_QLocale = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtCore_QLocale = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QLocale,
        SIP_NULLPTR,
        &plugin_QLocale,
    },
    {
        sipNameNr_QLocale,
        {0, 0, 1},
        60, methods_QLocale,
        825, enummembers_QLocale,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QLocale,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QLocale,
    init_type_QLocale,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QLocale,
    assign_QLocale,
    array_QLocale,
    copy_QLocale,
    release_QLocale,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QLocale,
    sizeof (::QLocale),
};
